package WebService::OurWorldInData::Catalog;
# ABSTRACT: Provides a limited search of Our World in Data charts

use Moo;
extends 'WebService::OurWorldInData';

use Carp;
use JSON qw(decode_json);
use PerlX::Maybe qw( maybe provided );
use Types::Standard qw( Str Bool Enum ); # Int ArrayRef HashRef InstanceOf ConsumerOf

has query => (
    is  => 'rw',
    isa => Str,
);

# list of all the known charts
# should make it a constant
my @data = <DATA>;
chomp @data;

=head1 NAME

WebService::OurWorldInData::Catalog

=head1 SYNOPSIS

    my $catalog = WebService::OurWorldInData::Catalog->new;

    my $results = $chart->find( 'covid' ); # get charts for covid
    my @topics  = $chart->get_topics;

=head1 DESCRIPTION

Pretends to search Our World in Data for data charts like the python api C<find>.

=head1 Methods

=head2 find

Returns an array ref of charts matching the argument to C<find>.
You can give it a string or a regex as in

    $results = $chart->find( qr/covid|death/ );

An empty call to C<find> will return all the charts it knows about.

    $all_results = $chart->find;

Our World in Data holds the data on 14,368 charts across 123 topics
as of July 2025. Because they haven't opened up their Catalog API yet,
I've had to scrape their web page for results. This means that the
C<find> method is not dynamic, up-to-date or anywhere near complete.

There are currently 3659 charts known by this module,
so you've got a 1 in 4 chance of finding what you're looking for.

=head2 get_topics

This will return a list of topics that I've scraped so far.
There are only 29 of the 123 known as of July 2025, but it should
give you a start.

=head1 SEE ALSO

=over 4

=item * L<HTTP::Tiny>

=back

=cut

sub get_path {
    my $self = shift;
    return join '/', $self->base_url, 'data';
}

sub find {
    my ($self, $query) = @_;

    $query = qr// unless defined $query;
    $query = qr/$query/ unless ref $query eq 'Regexp';
    my @hits = grep { /$query/ } @data;
    return \@hits;

    # if we ever get an api to the data endpoint
    #return $self->get_response( $url, { q => $query } );
}

sub get_topics {
    return qw(
        age-structure
        agricultural-production
        air-pollution
        alcohol-consumption
        animal-welfare
        antibiotics
        artificial-intelligence
        biodiversity
        books
        burden-of-disease
        cancer
        cardiovascular-diseases
        causes-of-death
        child-labor
        child-mortality
        clean-water
        clean-water-sanitation
        climate-change
        co2-and-greenhouse-gas-emissions
        coronavirus
        corruption
        crop-yields
        democracy
        diarrheal-diseases
        diet-compositions
        economic-growth
        economic-inequality
        economic-inequality-by-gender
        electricity-mix
        employment-in-agriculture
        energy
        energy-access
        energy-mix
        environmental-impacts-of-food
        eradication-of-diseases
        famines
        farm-size
        female-labor-supply
        fertility-rate
        fertilizers
        financing-education
        financing-healthcare
        fish-and-overfishing
        food-prices
        food-supply
        foreign-aid
        forests-and-deforestation
        fossil-fuels
        gender-ratio
        global-education
        government-spending
        happiness-and-life-satisfaction
        health-meta
        hiv-aids
        homelessness
        homicides
        human-development-index
        human-height
        human-rights
        hunger-and-undernourishment
        illicit-drug-use
        indoor-air-pollution
        influenza
        internet
        land-use
        lead-pollution
        lgbt-rights
        life-expectancy
        light-at-night
        literacy
        malaria
        marriages-and-divorces
        maternal-mortality
        meat-production
        mental-health
        metals-minerals
        micronutrient-deficiency
        migration
        military-personnel-spending
        mpox
        natural-disasters
        neglected-tropical-diseases
        nuclear-energy
        nuclear-weapons
        obesity
        oil-spills
        outdoor-air-pollution
        ozone-layer
        pandemics
        pesticides
        plastic-pollution
        pneumonia
        polio
        population-growth
        poverty
        renewable-energy
        research-and-development
        sanitation
        smallpox
        smoking
        social-connections-and-loneliness
        space-exploration-satellites
        state-capacity
        suicide
        taxation
        technological-change
        terrorism
        tetanus
        time-use
        tourism
        trade-and-globalization
        transport
        trust
        tuberculosis
        urbanization
        vaccination
        violence-against-rights-for-children
        war-and-peace
        waste-management
        water-use-stress
        wildfires
        women-rights
        working-hours
    );
}

1;

__DATA__
5-year-survival-rate-of-cancers-among-female-patients-in-england
above-ground-biomass-in-forest-per-hectare
abs-change-energy-consumption
absolute-change-co2
absolute-gains-in-mean-female-height
absolute-number-of-deaths-from-ambient-particulate-air-pollution
absolute-number-of-deaths-from-household-air-pollution
absolute-number-of-deaths-from-outdoor-air-pollution
academic-freedom-index
access-drinking-water-stacked
accessibility-of-statins-in-the-public-health-sector
access-to-basic-services
access-to-clean-fuels-and-technologies-for-cooking
access-to-clean-fuels-and-technologies-for-cooking-vs-per-capita-energy-consumption
access-to-clean-fuels-for-cooking-vs-gdp-per-capita
access-to-electricity-urban-vs-rural
access-to-electricity-vs-gdp-per-capita
access-to-justice-men-row
access-to-justice-women-row
access-to-sexual-health-care-and-education
ace-north-atlantic-hurricanes
acres-burned-per-wildfire-usa
acres-burned-usa
active-mobile-money-accounts
adequacy-of-social-insurance-programs
adequacy-of-social-safety-net-programs
adequacy-of-unemployment-benefits
adjusted-net-saving-current-us-dollars
adjusted-net-savings-per-person
adolescent-fertility
adolescent-fertility-15-19
adolescents-not-in-school
adoption-of-mobile-money-accounts-vs-adoption-of-mobile-phones
adoption-of-new-icd-guidelines-who-mortality-database
adult-literacy-female
adult-literacy-male
adult-obesity-vs-protein
adult-population-covered-in-primary-data-on-the-prevalence-of-major-depression
adult-population-covered-in-primary-data-on-the-prevalence-of-mental-illnesses
affected-by-disasters-vs-gdp
affiliation-researchers-building-artificial-intelligence-systems-all
african-elephant-carcass-ratio
african-elephants
age-at-marriage-women
age-dependency-breakdown
age-dependency-ratio-of-working-age-population
age-dependency-ratio-old
age-dependency-ratio-projected-to-2100
age-dependency-ratio-young-of-working-age-population
age-group-with-the-largest-population
age-of-consent-same-sex-different-sex-partners
age-of-consent-same-sex-partners-equaldex
age-of-democracy-polity
age-of-electoral-democracy
age-of-electoral-democracy-lexical
age-of-full-democracy
age-of-liberal-democracy-row
age-of-mothers-at-childbirth-by-year
age-standardized-death-rate-by-cause
age-standardized-deaths-from-all-causes
age-when-first-had-anxiety-depression
agricultural-area-per-capita
agricultural-export-subsidies
agricultural-land
agricultural-land-area-by-farm-size
agricultural-land-irrigation
agricultural-output-dollars
agricultural-producer-support
agricultural-water-as-a-share-of-total-water-withdrawals
agricultural-water-withdrawals
agricultural-water-withdrawals-vs-gdp-per-capita
agriculture-more-less-land
agriculture-orientation-index
agri-environmental-policies-gdp
agri-environmental-policies-intensity
ai-performance-coding-math-knowledge-tests
ai-performance-imagenet
ai-performance-knowledge-tests-vs-dataset-size
ai-performance-knowledge-tests-vs-parameters
ai-performance-knowledge-tests-vs-training-computation
air-conditioners-projections
ai-related-patents-applications-and-patents-granted
airline-capacity-and-traffic
airline-passenger-load-factor
airliner-hijackings-and-fatalities-from-them
air-passenger-kilometers
air-passengers-carried
air-passengers-per-fatality
air-pollutant-emissions
air-pollution-deaths-by-age
air-pollution-deaths-country
air-pollution-london-vs-delhi
air-pollution-vs-gdp-per-capita
air-transport-freight-ton-km
air-trips-per-capita
ai-training-computation-vs-parameters-by-domain
ai-training-computation-vs-parameters-by-researcher-affiliation
almond-yields
ambient-pollution-death-rates-2017-1990
americans-worry-work-being-automated
amount-of-foreign-aid-spend-in-recipient-countries
anemia-pregnant-women-vs-children
anemia-risk-groups
animal-lives-lost-direct
animal-lives-lost-total
animal-protein-consumption
animal-protein-vs-gdp
animals-slaughtered-for-meat
annual-afforestation
annual-area-burnt-by-wildfires
annual-area-burnt-by-wildfires-gwis
annual-area-burnt-per-wildfire
annual-area-burnt-per-wildfire-vs-number-of-fires
annual-broad-money-growth
annual-burned-area-by-landcover
annual-carbon-dioxide-emissions
annual-change-coal
annual-change-forest-area
annual-change-fossil-fuels
annual-change-gas
annual-change-hydro
annual-change-in-average-female-height
annual-change-in-average-male-height
annual-change-in-solar-and-wind-energy-generation
annual-change-low-carbon-energy
annual-change-nuclear
annual-change-oil
annual-change-primary-energy-source
annual-change-renewables
annual-change-solar
annual-change-wind
annual-co2-cement
annual-co2-coal
annual-co2-emissions-per-country
annual-co2-flaring
annual-co2-gas
annual-co2-including-land-use
annual-co2-oil
annual-co2-other-industry
annual-co-emissions-by-region
annual-co-emissions-from-aviation
annual-death-rate-by-age-group
annual-death-rates-in-different-age-groups
annual-death-rates-in-different-age-groups-by-sex
annual-death-rates-in-different-age-groups-females
annual-death-rates-in-different-age-groups-males
annual-deaths-by-age
annual-deaths-by-age-england-and-wales
annual-deaths-from-outdoor-air-pollution-by-region
annual-deforestation
annual-fish-catch-taxa
annual-forest-expansion
annual-freshwater-withdrawals
annual-gdp-growth
annual-growth-of-general-government-final-consumption-expenditure
annual-growth-of-the-gross-capital-formation
annual-growth-rate-of-urban-population-share
annual-healthcare-expenditure-per-capita
annual-industrial-robots-installed
annual-mortality-rate-from-seasonal-influenza-ages-65
annual-number-of-births-by-world-region
annual-number-of-deaths-by-cause
annual-number-of-deaths-by-world-region
annual-number-of-dhs-surveys-by-type
annual-number-of-fires
annual-number-of-people-receiving-antiretroviral-therapy-through-pepfar
annual-patent-applications
annual-patents-invention-united-states-1790
annual-per-capita-consumption-books
annual-percentage-change-coal
annual-percentage-change-fossil-fuels
annual-percentage-change-gas
annual-percentage-change-hydro
annual-percentage-change-in-solar-and-wind-energy-generation
annual-percentage-change-low-carbon
annual-percentage-change-nuclear
annual-percentage-change-oil
annual-percentage-change-renewables
annual-percentage-change-solar
annual-percentage-change-wind
annual-pm25-emissions-from-wildfires
annual-population-growth
annual-primary-energy-fossil-vs-low-carbon
annual-professional-service-robots-installed-by-area
annual-rate-of-change-in-urban-populations
annual-reported-ai-incidents-controversies
annual-reported-passenger-kilometers
annual-research-and-development-funding-for-technologies-infectious-diseases
annual-research-development-funding-for-neglected-tropical-diseases
annual-salary-of-primary-teachers-with-10-years-of-experience
annual-scholarly-publications-on-artificial-intelligence
annual-share-of-co2-emissions
annual-space-visits
annual-temperature-anomalies
annual-working-hours-per-person-employed
annual-working-hours-per-worker
annual-working-hours-per-worker-vs-gdp-per-capita-long-run
annual-working-hours-vs-gdp-per-capita-pwt
anorexia-bulimia-nervosa-estimated-cases
antarctica-sea-ice-extent
antarctic-ozone-hole-area
anthromes
antibiotic-consumption-rate
antibiotic-usage-by-surveillance-category-stacked
antibiotic-usage-by-surveillance-category-time
antibiotic-usage-in-children
antibiotic-usage-in-livestock
antibiotic-use-in-livestock-in-europe
antibiotic-use-intensity-in-livestock-by-region
antibiotic-use-livestock-marimekko
antibiotic-use-livestock-per-kg
antibiotic-use-livestock-tonnes
antidepressants-per-capita
antidepressants-per-capita-vs-gdp
antiretroviral-therapy-coverage-among-people-living-with-hiv
anxiety-disorders-prevalence
anxiety-disorders-prevalence-by-age
anxiety-disorders-prevalence-males-vs-females
anxiety-disorders-prevalence-vs-gdp
anxiety-disorders-treatment-gap
apple-production
aquaculture-farmed-fish-production
arable-land-pin
arable-land-use-per-person
arctic-sea-ice
area-burned-wildfires-by-type
area-land-needed-to-global-oil
area-meadows-and-pastures
area-of-permanent-meadows-and-pastures
area-per-tonne-oil
armed-forces-personnel
armed-forces-personnel-of-total-labor-force
armed-forces-personnel-percent
artificial-intelligence-granted-patents-by-industry
artificial-intelligence-number-training-datapoints
artificial-intelligence-parameter-count
artificial-intelligence-patents-submitted
artificial-intelligence-patents-submitted-per-million
artificial-intelligence-training-computation
artificial-intelligence-training-computation-by-researcher-affiliation
asthma-prevalence
attendance-major-artificial-intelligence-conferences
attitudes-bans-factory-farming
augmented-hdi-vs-gdp-per-capita
augmented-human-development-index
augmented-human-development-index-comparison
augmented-human-development-index-excluding-gdp
automated-teller-machines-atms-per-100000-adults
autopsy-rate
autumn-temperature-anomalies
availability-of-computed-tomography-ct-imaging
availability-of-positron-emission-tomography-pet-imaging
average-age-of-mothers-birth-cohort
average-ammonium-concentration-in-freshwater
average-battery-cell-price
average-cost-of-tuberculosis-treatment-by-type
average-daily-hours-of-work-by-occupation-united-states
average-daily-hours-of-work-in-winter-by-industry
average-daily-hours-worked-by-industry-united-states
average-daily-minutes-of-work-in-summer-by-industry
average-daily-time-spent-by-women-on-domestic-work-paid-and-unpaid
average-effective-retirement-men
average-effective-retirement-women
average-expenditures-of-international-tourists-domestically
average-expenditures-of-tourists-abroad
average-exposure-pm25-pollution
average-farm-size
average-farm-size-vs-gdp
average-harmonized-learning-outcome-scores
average-height-by-year-of-birth
average-height-of-men
average-height-of-men-by-year-of-birth
average-height-of-men-for-selected-countries
average-height-of-women
average-hours-of-work-per-day-by-industry
average-hours-of-work-per-week-by-industry
average-learning-outcomes-by-total-education-expenditure-per-capita
average-length-of-stay
average-literacy-score-piaac-test-vs-national-literacy-rate-cia
average-monthly-surface-temperature
average-nitrate-concentration-in-freshwater
average-non-hdl-cholesterol-levels
average-oecd-education-expenditure-by-source-of-funding-gdp
average-performance-of-15-year-old-girls-and-boys-on-the-science-scale
average-performance-of-15-year-olds-in-mathematics-reading-and-science
average-performance-of-15-year-olds-on-the-science-scale
average-phosphorus-concentration-in-freshwater
average-precipitation-per-year
average-schooling-vs-expected-schooling
average-usual-weekly-hours-worked-women-15-years-and-older
average-working-hours-of-children
average-years-of-schooling
average-years-of-schooling-males-vs-females
average-years-of-schooling-vs-corruption-perception-index
average-years-of-schooling-vs-gdp-per-capita
avertable-deaths-from-rotavirus-with-full-vaccine-coverage
aviation-accidents-by-flight-phase
aviation-demand-efficiency
aviation-fatalities-by-flight-phase
aviation-fatalities-per-million-passengers
aviation-share-co2
banana-production
banana-yields
bank-capital-to-total-assets-ratio
banning-of-chick-culling
barley-yields
basic-state-functions-score-bti
bathing-sites-with-excellent-water-quality
battery-plugin-hybrid-vehicles
bcg-immunization-coverage-for-tb-among-1-year-olds
bean-yields
beef-and-buffalo-meat-production-tonnes
bev-share-new-ev
biofuel-production
biofuels-production-by-region
biological-weapons
biological-weapons-convention
biomass-fish-stocks-region
biomass-fish-stocks-taxa
biomass-vs-abundance-taxa
bipolar-disorder-prevalence
bipolar-disorder-prevalence-by-age
bipolar-disorder-prevalence-males-vs-females
bird-populations-eu
birth-rate-colored-by-peak-birth-month
birth-rate-total
birth-rate-vs-death-rate
births-and-deaths
births-and-deaths-projected-to-2100
births-by-age-of-mother
births-per-month-annual
births-registered
black-rhinos
bladder-cancer-death-rate
bleaching-events-enso
blood-donations-men-sex-with-men
borrowing-to-start-or-expand-business-men-vs-women
bottom-trawling
brain-and-nervous-system-cancer-death-rate
breakdown-habitable-land
breakdown-of-child-mortality-by-cause
breast-cancer-death-rate-in-women
breast-cancer-screening-coverage-in-europe
bribe-payers-index
bribery-incidence-for-firms
bribery-prevalence-un
britain-road-deaths-user
broadband-penetration-by-country
broad-causes-of-death
broad-money-to-total-reserves-ratio
budget-to-manage-invasive-alien-species
bullfighting-ban
burden-disease-from-each-mental-illness
burden-of-disease
burden-of-disease-by-cause
burden-of-disease-from-injuries-by-age
burden-of-disease-rates-from-communicable-neonatal-maternal-nutritional-diseases
burden-of-disease-rates-from-injuries
burden-of-disease-rates-from-ncds
burden-of-disease-who
calorie-supply-by-food-group
calories-wasted-food-group
cancer-crude-death-rate-by-type
cancer-death-rate-by-age-group
cancer-death-rate-crude-vs-age-standardized-who-mdb
cancer-death-rate-in-children-under-5-years-old-by-type
cancer-death-rates
cancer-death-rates-by-age
cancer-death-rates-by-type
cancer-death-rates-by-type-who-db
cancer-death-rates-in-children-under-10-years-old
cancer-death-rate-who-mdb
cancer-deaths-by-age
cancer-deaths-by-type-grouped
cancer-deaths-in-children-under-5-years-old-by-type
cancer-deaths-rate-and-age-standardized-rate-index
cancer-incidence
cancer-incidence-rate-by-age-group
cancer-screening-rates-in-europe
cantril-ladder-age-groups
capital-city-population
capital-intensity
capital-intensity-vs-labor-productivity
capture-and-aquaculture-production
capture-fisheries-vs-aquaculture
capture-fishery-production
carbon-dioxide-emissions-factor
carbon-emissions-trading-system
carbon-footprint-travel-mode
carbon-intensity-electricity
carbon-intensity-vs-gdp
carbon-new-passenger-vehicles
carbon-opportunity-costs-per-kilogram-of-food
carbon-tax-instruments
carbon-tax-trading-coverage
cardiac-magnetic-resonance-imaging-mri-availability
cardiac-procedures-per-million-people
cardiac-surgeons-per-million-people
cardiovascular-death-rate-vs-gdp-per-capita
cardiovascular-disease-death-crude-rate-who-mdb
cardiovascular-disease-death-rate-age-group-who-mdb
cardiovascular-disease-death-rate-crude-versus-age-standardized
cardiovascular-disease-death-rate-males-vs-females
cardiovascular-disease-death-rate-over-time-males-vs-females
cardiovascular-disease-death-rates
cardiovascular-disease-death-rates-by-age
cardiovascular-disease-death-rate-who-mdb
cardiovascular-disease-deaths-by-age
cardiovascular-diseases-deaths-by-risk-factor
caribbean-acropora
car-sales
cases-and-deaths-from-vaccine-preventable-diseases
cases-of-extensively-drug-resistant-tuberculosis
cases-of-killed-human-rights-defenders-journalists-trade-unionists
cases-of-multidrug-resistant-tuberculosis
cases-of-paralytic-polio-from-vaccine-derived-viruses
cases-of-paralytic-polio-from-vaccine-derived-viruses-by-strain
cases-of-paralytic-polio-from-wild-polioviruses
cases-of-paralytic-polio-from-wild-vs-vaccine-derived-viruses
cashew-nut-yields
cassava-production
cassava-yields
catch-fishing-power-uk
cattle-livestock-count-heads
cattle-meat-yields-hectograms-100-grams-per-animal
cause-of-death-registration-population
causes-of-death-in-15-49-year-olds
causes-of-death-in-50-69-year-olds
causes-of-death-in-5-14-year-olds
causes-of-death-in-70-year-olds
causes-of-death-in-children-under-5
censorship-of-lgbt-issues
census-based-on-population-register-recently-completed
cereal-crop-yield-vs-fertilizer-application
cereal-distribution-to-uses
cereal-land-spared
cereal-production
cereals-human-food-vs-gdp
cereals-imports-vs-exports
cereal-yield
cereal-yields-uk
cereal-yield-vs-extreme-poverty-scatter
cereal-yield-vs-gdp-per-capita
cervical-cancer-death-rate-in-women
cervical-cancer-screening-coverage-in-europe
change-air-pollutant-emissions
change-co2-annual-pct
change-energy-consumption
change-energy-gdp-per-capita
change-forest-area-share-total
change-forest-vs-gdp
change-heat-death-rate
change-heat-deaths-gdp
change-in-male-height
change-in-production-yield-and-land-palm
change-in-total-mangrove-area
change-marine-mammals
change-of-cereal-yield-vs-land-used
changes-uk-butterfly
chemical-weapons
chemical-weapons-convention
chicken-meat-production
chicken-meat-yields-per-animal
child-and-maternal-malnutrition-death-rate
child-death-change
child-death-rates-by-cause
child-deaths-by-source
child-deaths-by-world-region-un-data
child-deaths-from-rotavirus
child-deaths-from-streptococcus-by-disease
child-deaths-igme-data
child-deaths-life-stage
child-deaths-malnutrition-by-risk
child-homicide-rate
child-homicide-rate-per-100000
childhood-deaths-from-the-five-most-lethal-infectious-diseases-worldwide
child-marriage-prohibited-or-invalidated
child-maternal-malnutrition-gdp
child-mortality
child-mortality-around-the-world
child-mortality-by-income-level-of-country
child-mortality-by-sex
child-mortality-by-the-type-of-congenital-birth-defect
child-mortality-from-ari-vs-treatment
child-mortality-gdp-per-capita
child-mortality-igme
child-mortality-line-chart-by-sex
child-mortality-rate-ihme
child-mortality-rate-including-un-projections-through-2100
child-mortality-rate-marimekko
child-mortality-rate-vs-mean-male-height-cm
child-mortality-respiratory-infections-vs-clean-fuels
child-mortality-under-five-death-rate-by-wealth-group
child-mortality-vs-co2-emissions-per-capita
child-mortality-vs-electoral-democracy
child-mortality-vs-health-expenditure
child-mortality-vs-level-of-prosperity-regression
child-mortality-vs-population-growth
child-mortality-vs-share-of-children-immunized-against-diphtheria-pertussis-and-tetanus
children-age-15-who-report-physical-punishment-by-teachers
children-age-8-who-report-physical-punishment-by-teachers
children-aged-5-17-engaged-in-labor
children-aged-5-17-years-engaged-in-labor
children-and-youth-out-of-school
children-born-per-woman
children-died-before-five-per-woman
children-in-employment-ages-7-14-vs-weekly-hours-worked-by-children-ages-7-14
children-per-woman-fertility-rate-vs-level-of-prosperity
children-per-woman-un
children-per-woman-vs-human-development-index
children-per-woman-vs-population-growth
children-treated-ari
children-under-age-5
children-who-experience-violent-discipline-boys-vs-girls
children-who-experience-violent-discipline-vs-gdp-per-capita
children-woman-death-vs-survival
chlorophyll-a-deviation-from-the-global-average
chocolate-consumption-per-person
chronic-respiratory-diseases-death-rate-who-mdb
citizen-satisfaction-with-democracy
citizen-support-for-democracy
city-populations-to-2035
civilian-and-combatant-deaths-in-armed-conflicts
civilian-and-combatant-deaths-in-armed-conflicts-based-on-where-they-occurred
civil-liberties-index-eiu
civil-liberties-rating-fh
civil-liberties-score-fh
civil-rights-score-bti
civil-society-participation-index
clientelism-index
co2-by-source
co2-consumption-share
co2-deforestation-for-food
co2-emissions-and-gdp
co2-emissions-and-gdp-long-term
co2-emissions-and-gdp-per-capita
co2-emissions-by-fuel-line
co2-emissions-domestic-aviation
co2-emissions-fossil-land
co2-emissions-transport
co2-emissions-vs-gdp
co2-fossil-plus-land-use
co2-gdp-growth
co2-gdp-pop-growth
co2-heating-cooling
co2-income-level
co2-intensity
co2-international-aviation
co2-land-use
co2-land-use-global-share
co2-land-use-per-capita
co2-long-term-concentration
co2-mitigation-15c
co2-mitigation-2c
co2-per-capita-marimekko
co2-per-capita-vs-renewable-electricity
co2-per-unit-energy
coal-by-end-user-uk
coal-consumption-by-country-terawatt-hours-twh
coal-consumption-by-region
coal-consumption-per-capita
coal-electricity-per-capita
coal-energy-share
coal-output-per-worker-in-the-united-kingdom
coal-output-uk-tonnes
coal-phase-out-timeline
coal-prices
coal-prod-per-capita
coal-production-by-country
coal-production-by-region
coal-production-country
coal-production-per-capita-over-the-long-term
coal-proved-reserves
coal-reserves-by-type
coal-uk-opencast-deep-mine
coal-vs-gdp-per-capita
coastal-eutrophication
cobalt-production
cocoa-bean-production
cocoa-bean-yields
coefficient-of-variation-cv-in-per-capita-caloric-intake
coefficient-of-variation-in-caloric-consumption-vs-gdp-per-capita
co-emissions-by-sector
co-emissions-embedded-in-global-trade
co-emissions-per-capita
co-emissions-per-capita-vs-fossil-fuel-consumption-per-capita
coffee-bean-production
coffee-production-by-region
coffee-yields
cohort-fertility-rate
cohort-fertility-rate-by-age
colon-and-rectum-cancer-death-rate
colon-and-rectum-cancer-screening-coverage-in-europe
comfort-speaking-vs-knowing-friends-family-with-anxiety-depression
commodity-deforestation-by-region
commodity-driven-deforestation
common-good-justifications-score
community-health-workers
companies-publishing-sustainability-reports-minimum-requirements
compare-sources-working-hours
comparison-of-fertility-rates
comparison-of-world-population-projections
competitive-elections-lexical
completeness-of-homelessness-data
completion-rate-of-lower-secondary-education
completion-rate-of-primary-education
completion-rate-of-upper-secondary-education-sdg
composition-of-tax-revenues-regional
comprehensive-nuclear-test-ban-treaty
computer-chess-ability
confidence-in-the-effectiveness-of-vaccines-vs-perception-of-importance
confidence-in-un-wvs
confirmed-tb-cases-vs-rifampicin-resistant-tb-cases
congenital-birth-defect-mortality-rates-in-children-under-5
constitutional-protections-lgbt
consumption-based-carbon-intensity
consumption-based-energy-per-capita
consumption-co2-emissions
consumption-co2-per-capita
consumption-co2-per-capita-equity
consumption-co2-per-capita-vs-gdppc
consumption-energy-intensity
consumption-of-oral-antibiotics-by-type
consumption-of-ozone-depleting-substances
consumption-subsidies-for-fossil-fuels
contraceptive-prevalence-any-methods-of-women-ages-15-49
contraceptive-prevalence-any-methods-vs-modern-methods
contributions-global-temp-change
contribution-temp-rise-degrees
contribution-to-temp-rise-by-gas
conversion-therapies-banned
conversion-therapy-equaldex
coral-bleaching-events
corporate-investment-in-artificial-intelligence-by-type
correlation-between-child-mortality-and-mean-years-of-schooling-for-those-aged-15-and-older
cost-of-sequencing-a-full-human-genome
cost-per-gigabase-dna-sequencing
costs-of-66-different-technologies-over-time
costs-of-polio-vaccines-in-low-income-countries
cost-space-launches-low-earth-orbit
cotton-yield
countries-by-legal-status-of-same-sex-marriage
countries-by-share-of-women-in-parliament
countries-data-antibiotic-livestock
countries-democracies-autocracies-bti
countries-democracies-autocracies-lexical
countries-democracies-autocracies-row
countries-democracies-nondemocracies-eiu
countries-democracies-nondemocracies-fh
countries-democracies-nondemocracies-polity
countries-enrolled-in-glass-surveillance-of-antimicrobial-consumption-and-resistance
countries-in-which-gender-marker-can-be-legally-changed
countries-in-which-same-sex-sexual-acts-are-legal
countries-joint-adoptions-same-sex-partners
countries-long-standing-democracies-polity
countries-long-standing-electoral-democracies
countries-long-standing-electoral-democracies-lexical
countries-long-standing-liberal-democracies-row
countries-protecting-core-lgbt-rights
countries-reporting-progress-in-multi-stakeholder-development-effectiveness-monitoring-frameworks-in-support-of-the-sdgs
countries-submit-antimicrobial-data-woah
countries-that-adopt-guarantees-for-public-access-to-information
countries-that-are-democratizing-and-autocratizing
countries-that-are-democratizing-and-autocratizing-within-regimes
countries-that-are-long-standing-full-democracies
countries-that-are-parties-to-the-nagoya-protocol
countries-that-have-universal-voting-rights
countries-third-gender-recognized
countries-to-access-and-benefit-sharing-clearing-house
countries-to-montreal-protocol-and-vienna-convention
countries-to-the-international-treaty-on-plant-genetic-resources
countries-using-ecosystem-based-approaches-to-manage-marine-areas
countries-where-interstate-or-intrastate-wars-took-place
countries-with-an-inforce-bilateral-investment-treaty
countries-with-a-signed-bilateral-investment-treaty
countries-with-independent-national-human-rights-institution
countries-with-minimum-urban-threshold
countries-with-national-adaptation-plans-for-climate-change
countries-with-national-cervical-cancer-screening-program
country-has-a-civil-register
country-has-a-statistical-agency
country-level-monthly-temperature-anomalies
country-position-nuclear-weapons
country-scp-plan
coverage-by-protected-areas-of-important-sites-for-mountain-biodiversity
coverage-of-the-human-papillomavirus-vaccine
coverage-of-wetlands
covid-people-vaccinated-marimekko
covid-vaccinations-vs-covid-death-rate
covid-vaccine-share-boosters
covid-world-unvaccinated-people
criminal-penalties-or-civil-remedies-sexual-harassment-in-employment
crop-allocation-farm-size
cropland-area
cropland-pasture-per-person
cropland-per-person-over-the-long-term
cropland-use-over-the-long-term
cross-country-literacy-rates
cross-country-variation-in-altruism
cross-country-variation-in-negative-reciprocity
cross-country-variation-in-patience
cross-country-variation-in-positive-reciprocity
cross-country-variation-in-risk-taking
crude-birth-rate
crude-death-rate
crude-death-rate-hmd
crude-death-rate-the-share-of-the-population-that-dies-each-year-gbd
crude-death-rate-the-share-of-the-population-that-dies-each-year-who
crude-death-rate-the-share-of-the-population-that-dies-per-year
crude-oil-prices
crude-oil-spot-prices
cumulative-area-burnt-by-wildfires-by-week
cumulative-area-burnt-by-wildfires-in-2024
cumulative-co2-cement
cumulative-co2-coal
cumulative-co2-emissions-region
cumulative-co2-flaring
cumulative-co2-fuel
cumulative-co2-gas
cumulative-co2-including-land
cumulative-co2-land-use
cumulative-co2-oil
cumulative-co-emissions
cumulative-co-emissions-released-by-wildfires-by-week
cumulative-co-emissions-released-by-wildfires-in-2024
cumulative-cohort-fertility-rate-by-age
cumulative-covid-vaccinations-income-group
cumulative-death-rates-in-armed-conflicts
cumulative-deaths-in-armed-conflicts
cumulative-deaths-in-armed-conflicts-by-country-region-and-type
cumulative-deaths-in-armed-conflicts-by-type
cumulative-exoplanets-by-method
cumulative-gravitational-wave-observations
cumulative-installed-wind-energy-capacity-gigawatts
cumulative-lives-saved-by-measles-vaccination-since-1974
cumulative-lives-saved-vaccination
cumulative-number-artificial-intelligence-bills-passed
cumulative-number-of-dhs-surveys-conducted
cumulative-number-of-large-scale-ai-models-by-domain
cumulative-number-of-large-scale-ai-systems-by-country
cumulative-number-of-notable-ai-systems-by-domain
cumulative-number-of-objects-launched-into-outer-space
cumulative-people-space
cumulative-space-visits
current-account-balance-as-a-proportion-of-gdp
daily-cases-covid-region
daily-hours-spent-with-digital-media-per-adult-user
daily-mean-income
daily-meat-consumption-per-person
daily-new-confirmed-covid-19-deaths-in-sweden-oct-2020
daily-per-capita-caloric-supply
daily-per-capita-fat-supply
daily-per-capita-fat-supply-vs-gdp-per-capita
daily-per-capita-protein-supply
daily-per-capita-protein-supply-vs-gdp-per-capita
daily-per-capita-supply-of-calories-vs-gdp-per-capita
daily-protein-supply-from-animal-and-plant-based-foods
daily-protein-supply-of-animal-origin-vs-plant-origin
daily-tests-and-daily-new-confirmed-covid-cases
daly-rates-from-all-causes-by-age
dalys-particulate-matter
dalys-rate-from-all-causes
dalys-to-ncds-vs-gdp
damage-costs-from-natural-disasters
date-of-the-peak-cherry-tree-blossom-in-kyoto
days-of-vacation-and-holidays
dealing-with-anxiety-depression-approaches
dealing-with-anxiety-depression-comparison
dealt-with-anxiety-depression-friends-family
dealt-with-anxiety-depression-religious-spiritual
dealt-with-anxiety-depression-took-prescribed-medication
death-rate-ambient-air-pollution
death-rate-amphetamine
death-rate-amphetamine-who
death-rate-by-age-group-in-england-and-wales
death-rate-by-cause-who-mdb
death-rate-by-source-from-air-pollution
death-rate-by-source-from-indoor-air-pollution
death-rate-from-air-pollution-per-100000
death-rate-from-alzheimers-other-dementias-gbd
death-rate-from-alzheimers-other-dementias-ghe
death-rate-from-ambient-particulate-air-pollution
death-rate-from-cancer
death-rate-from-cancer-by-sex
death-rate-from-cancer-for-15-to-49-year-olds
death-rate-from-cancer-gbd
death-rate-from-cancers-vs-average-income
death-rate-from-cancers-vs-income-inequality
death-rate-from-cardiomyopathy-myocarditis-endocarditis-who-ghe-age-standardized
death-rate-from-cardiovascular-disease-age-standardized-ghe
death-rate-from-cardiovascular-disease-for-15--to-49-year-olds
death-rate-from-cardiovascular-disease-ghe
death-rate-from-cardiovascular-diseases
death-rate-from-cardiovascular-diseases-age-group-who-mdb
death-rate-from-cardiovascular-diseases-by-risk-factor-age-standardized
death-rate-from-communicable-vs-non-communicable-diseases
death-rate-from-diabetes
death-rate-from-diabetes-gbd
death-rate-from-diabetes-ghe
death-rate-from-diabetes-who-mdb
death-rate-from-digestive-diseases
death-rate-from-digestive-diseases-gbd
death-rate-from-digestive-diseases-who-mdb
death-rate-from-drowning
death-rate-from-drowning-ghe
death-rate-from-drug-use-disorders-for-15--to-49-year-olds
death-rate-from-falls
death-rate-from-falls-gbd
death-rate-from-falls-gbd-rate
death-rate-from-fires-and-burns-ihme
death-rate-from-fires-and-burns-who
death-rate-from-hypertensive-heart-disease-who-ghe-age-standardized
death-rate-from-indoor-air-pollution-vs-per-capita-energy-consumption
death-rate-from-ischaemic-heart-disease-who-ghe-age-standardized
death-rate-from-liver-disease
death-rate-from-liver-disease-gbd
death-rate-from-malnutrition
death-rate-from-malnutrition-ghe
death-rate-from-maternal-disorders
death-rate-from-maternal-disorders-ihme
death-rate-from-meningitis
death-rate-from-meningitis-gbd
death-rate-from-meningitis-who
death-rate-from-mental-health-and-substance-use-disorders-who
death-rate-from-natural-disasters
death-rate-from-obesity-gbd
death-rate-from-opioid-use
death-rate-from-opioid-use-who
death-rate-from-ozone-pollution
death-rate-from-ozone-pollution-gbd
death-rate-from-parkinsons-disease
death-rate-from-parkinsons-disease-gbd
death-rate-from-parkinsons-disease-ghe
death-rate-from-pm25-vs-pm25-concentration
death-rate-from-pneumonia-gbd
death-rate-from-pneumonia-ghe
death-rate-from-poisoning
death-rate-from-poisoning-gbd
death-rate-from-poisoning-ghe
death-rate-from-poisonings
death-rate-from-respiratory-infections
death-rate-from-respiratory-infections-gbd
death-rate-from-rheumatic-heart-disease-who-ghe-age-standardized
death-rate-from-road-accidents
death-rate-from-road-accidents-for-15--to-49-year-olds
death-rate-from-road-accidents-ghe
death-rate-from-secondhand-smoke
death-rate-from-secondhand-smoke-gbd
death-rate-from-smoking
death-rate-from-snakebite-envenoming
death-rate-from-strokes
death-rate-from-strokes-who
death-rate-from-suicides
death-rate-from-suicides-ghe
death-rate-from-suicides-gho
death-rate-from-unsafe-sanitation
death-rate-from-unsafe-sanitation-gbd
death-rate-from-venomous-animal
death-rate-household-air-pollution
death-rate-household-and-ambient-air-pollution
death-rate-in-armed-conflicts
death-rate-in-armed-conflicts-by-type
death-rate-in-armed-conflicts-by-type-and-country
death-rate-indoor-pollution-1990-2017
death-rate-in-state-based-conflicts
death-rate-in-wars-correlates-of-war
death-rate-in-wars-project-mars
death-rate-road-traffic-injuries
death-rates-cocaine
death-rates-cocaine-overdoses-by-age
death-rates-cocaine-who
death-rates-disaster-gdp
death-rates-due-to-low-physical-activity
death-rates-due-to-low-physical-activity-gbd
death-rates-from-air-pollution
death-rates-from-conflict-and-terrorism-gbd
death-rates-from-disasters
death-rates-from-drug-use
death-rates-from-drug-use-disorders
death-rates-from-drug-use-disorders-gbd
death-rates-from-drug-use-disorders-who
death-rates-from-drug-use-gbd
death-rates-from-energy-production-per-twh
death-rates-from-high-blood-pressure
death-rates-from-high-blood-pressure-gbd
death-rates-from-high-blood-sugar
death-rates-from-high-blood-sugar-gbd
death-rates-from-indoor-air-pollution-gbd
death-rates-from-indoor-air-pollution-vs-gdp-per-capita
death-rates-from-indoor-air-pollution-vs-share-of-population-in-absolute-poverty
death-rates-from-mental-and-substance-disorders-by-age-who
death-rates-from-natural-disasters
death-rates-from-no-access-to-handwashing-facilities
death-rates-from-pneumonia-and-other-lower-respiratory-infections-vs-gdp-per-capita
death-rates-from-unsafe-sex
death-rates-from-unsafe-sex-gbd
death-rates-from-unsafe-water-sources-gbd
death-rates-opioid-overdoses-by-age
death-rates-road-incidents
death-rates-smoking-age
death-rates-through-the-20th-century
death-rates-unsafe-water
death-rates-unsafe-water-vs-gdp
death-rate-upper-respiratory-age
deaths-age-group-stacked-bar
deaths-amphetamine-overdoses-by-sex
deaths-and-disappearances-during-migration
deaths-attributed-to-household-air-pollution-vs-deaths-attributed-to-ambient-air-pollution
deaths-averted-due-to-rotavirus-vaccine
deaths-by-age-group
deaths-by-age-group-stacked
deaths-by-risk-factor-over-70
deaths-by-risk-under5s
deaths-caused-by-vaccine-preventable-diseases-over-time
deaths-cocaine-overdoses-by-sex
deaths-conflict-terrorism-per-100000
deaths-drug-overdoses
deaths-drug-overdoses-who
deaths-drug-use-disorders-by-sex
deaths-due-to-drug-use
deaths-due-to-high-blood-pressure
deaths-due-to-high-blood-sugar
deaths-due-to-illicit-drug-use-by-age
deaths-due-to-low-physical-activity
deaths-due-to-measles-by-region
deaths-due-to-measles-gbd
deaths-due-to-obesity
deaths-due-to-unsafe-sanitation
deaths-due-to-unsafe-sex
deaths-due-to-unsafe-water-sources
deaths-from-acute-hepatitis-by-age
deaths-from-acute-hepatitis-by-cause
deaths-from-air-pollution
deaths-from-alzheimers
deaths-from-alzheimers-other-dementias
deaths-from-cancer-gbd
deaths-from-cancer-who
deaths-from-cardiovascular-disease
deaths-from-cardiovascular-disease-ghe
deaths-from-cardiovascular-diseases-by-region
deaths-from-cardiovascular-disease-type
deaths-from-conflict-and-terrorism
deaths-from-cysticercosis
deaths-from-diabetes
deaths-from-diabetes-by-age
deaths-from-diabetes-by-type
deaths-from-diabetes-ghe
deaths-from-digestive-diseases
deaths-from-drowning
deaths-from-drowning-ghe
deaths-from-drug-use-disorders
deaths-from-drug-use-disorders-by-age
deaths-from-drug-use-disorders-by-age-who
deaths-from-drug-use-disorders-ghe
deaths-from-encephalitis-by-age
deaths-from-falls
deaths-from-falls-gbd
deaths-from-fires-and-burns
deaths-from-fires-and-burns-who
deaths-from-household-and-outdoor-air-pollution
deaths-from-indoor-air-pollution-by-age
deaths-from-infectious-diseases
deaths-from-liver-disease
deaths-from-lower-respiratory-infections-ghe
deaths-from-malnutrition
deaths-from-malnutrition-ghe
deaths-from-measles-by-age
deaths-from-meningitis
deaths-from-meningitis-by-age
deaths-from-meningitis-ghe
deaths-from-mental-health-and-substance-use-disorders-who
deaths-from-natural-disasters
deaths-from-obesity-by-age
deaths-from-one-sided-violence
deaths-from-ozone-pollution
deaths-from-parkinsons-disease
deaths-from-parkinsons-disease-ghe
deaths-from-pneumonia
deaths-from-pneumonia-in-people-aged-70-and-older-by-risk-factor
deaths-from-poisoning
deaths-from-poisonings-ghe
deaths-from-preterm-birth-complications
deaths-from-rabies-by-age
deaths-from-respiratory-disease
deaths-from-respiratory-infections
deaths-from-road-injuries
deaths-from-smallpox-in-london
deaths-from-smallpox-per-1000-population
deaths-from-snakebite-envenoming
deaths-from-strokes
deaths-from-strokes-ghe
deaths-from-substance-use-disorders
deaths-from-substance-use-disorders-who
deaths-from-suicide-and-non-suicide-terrorist-attacks
deaths-from-syphilis-by-age
deaths-from-terrorism-by-target
deaths-from-terrorist-attacks-by-method
deaths-from-terrorist-attacks-by-method-of-attack-stacked-bar
deaths-from-tobacco-smoking-by-age
deaths-from-venomous-animal-contact
deaths-from-volcanic-eruptions
deaths-from-yellow-fever-by-age
deaths-illicit-drugs
deaths-in-armed-conflicts
deaths-in-armed-conflicts-by-country
deaths-in-armed-conflicts-by-region
deaths-in-armed-conflicts-by-type
deaths-in-armed-conflicts-by-type-and-country
deaths-in-interstate-conflicts
deaths-in-interstate-conflicts-by-region-gibler-miller
deaths-in-interstate-conflicts-gibler-miller
deaths-in-intrastate-conflicts
deaths-in-non-state-conflicts
deaths-in-state-based-conflicts
deaths-in-state-based-conflicts-by-region
deaths-in-state-based-conflicts-by-type
deaths-in-wars
deaths-in-wars-by-region-project-mars
deaths-in-wars-by-war-1800-2011-bar-chart
deaths-in-wars-correlates-of-war
deaths-in-wars-project-mars
deaths-opioid-overdoses-by-sex
deaths-registered-with-an-ill-defined-cause-of-death
deaths-risk-factor-15-49years
deaths-risk-factor-50-69years
deaths-risk-factor-5-14years
deaths-substance-disorders
deaths-temperature-gasparrini
debt-service-of-exports-of-goods-services
decadal-average-surface-temperature
decadal-deaths-disasters-type
decadal-economic-disasters-type
decadal-temperature-anomaly
decade-in-which-smallpox-ceased-to-be-endemic-by-country
deforestation-by-commodity
deforestation-co2-trade-by-product
deforestation-drivers-indonesia
deforestation-share-forest-area
degree-to-which-the-legal-framework-guarantees-womens-equal-rights-to-land-ownership-andor-control
deliberative-democracy-index-vdem
deliberative-political-institutions-index
dementia-death-rates
dementia-related-deaths-by-age
democracies-autocracies-amb-row
democracy-index-by-source
democracy-index-eiu
democracy-index-polity
democratic-culture-index-eiu
democratic-electoral-institutions-fh
democratic-electoral-institutions-row
democratic-features-bti
demographic-and-health-surveys-that-were-ongoing-before-termination
demographic-transition-england-wales
demographic-transition-sweden
dengue-fever-deaths
dengue-incidence
dentistry-personnel-per-1000
depression-vs-self-reported-life-satisfaction
depressive-disorders-prevalence-by-age
depressive-disorders-prevalence-ihme
depressive-disorders-prevalence-ihme-vs-who
depressive-disorders-prevalence-males-vs-females
depressive-disorders-prevalence-vs-gdp-per-capita
depressive-symptoms-across-us-population
dhs-is-the-only-source-of-maternal-mortality-data
diabetes-prevalence
diabetes-prevalence-vs-gdp-per-capita
diabetes-prevalence-who-gho
diamond-production
diarrheal-disease-death-rates-in-children-under-5
diarrheal-diseases-vs-handwashing-facilities
dietary-choices-of-british-adults
dietary-choices-uk
dietary-land-use-vs-beef-consumption
dietary-land-use-vs-gdp-per-capita
difference-in-female-and-male-life-expectancy-at-age-45
difference-in-female-and-male-life-expectancy-at-birth
difference-in-life-expectancy-between-females-and-males-vs-child-mortality
difference-in-life-expectancy-between-females-and-males-vs-gdp-per-capita
difference-in-male-and-female-life-expectancy
difference-in-the-value-of-goods-exported-to-and-imported-by-the-us
diphtheria-cases-in-the-united-states
diphtheria-deaths
diphtheria-tetanus-pertussis-vaccine-vs-pneumococcal-vaccine-coverage
direct-democracy-index
direct-disaster-economic-loss
disaster-events-missing-data
disaster-risk-reduction-progress
discomfort-speaking-anxiety-depression
discomfort-speaking-anxiety-depression-by-gender
discrimination-access-to-credit-gender
discrimination-lgbt-equaldex
disease-burden-by-age
disease-burden-by-region
disease-burden-by-risk-factor
disease-burden-from-communicable-diseases
disease-burden-from-communicable-diseases-by-age
disease-burden-from-injuries
disease-burden-from-ncds
disease-burden-from-ncds-by-age
disease-burden-rates-by-cancer-types
disease-burden-rates-from-cancers
disease-burden-to-communicable-diseases-vs-gdp
disease-burden-vs-health-expenditure-per-capita
distribution-democracy-index-polity
distribution-of-bilateral-and-unilateral-trade-partnerships
divorces-per-1000-people
domain-notable-artificial-intelligence-systems
domestic-forest-change-vs-imported-deforestation
domestic-guests-in-tourism-accommodation-hotels-and-similar-establishments-vs-foreign-guests-in-tourism-accommodation-hotels-and-similar-establishments
domestic-policy-free-from-interference-of-other-states-score
donated-official-development-assistance-grants-for-poverty-reduction
drinking-water-service-coverage
drinking-water-services-coverage-rural
drinking-water-services-coverage-urban
drivers-forest-loss-brazil-amazon
drivers-of-recovery-in-european-bird-populations
drought-severity-index-us
drowning-death-rates
drowning-death-rates-under-5
drowning-deaths-by-age-group
drug-disorder-dalys-rate
drug-overdose-death-rates
drug-resistant-confirmed-cases-of-tuberculosis
dtp3-children-unvaccinated
duration-of-compulsory-education
duration-of-pre-primary-education
earthquake-deaths
eating-disorders-prevalence
eating-disorders-prevalence-by-age
eating-disorders-prevalence-males-vs-females
economic-complexity-rankings
effective-fertility-rate-children-per-woman-who-are-expected-to-survive-until-childbearing-age
effective-fertility-rates-malani-and-jacob
effective-power-to-govern-score-bti
efficiency-lighting-uk-sources
efficiency-of-lighting-in-the-united-kingdom-lumen-hours-per-kilowatt-hour
egalitarian-democracy-index-vdem
egalitarian-political-institutions-index
egg-production-system
egg-production-thousand-tonnes
eggs-cage-free
egg-yield-per-bird
elec-fossil-nuclear-renewables
elec-mix-bar
elected-political-leaders-index
elections-for-the-governments-chief-executive
elections-legislature-lexical
electoral-democracy-index
electoral-democracy-lexical
electoral-democracy-row
electoral-pluralism-index-eiu
electric-car-sales
electric-car-sales-share
electric-car-stocks
electricity-air-conditioning
electricity-as-a-share-of-primary-energy
electricity-coal
electricity-demand
electricity-fossil-fuels
electricity-fossil-renewables-nuclear-line
electricity-gas
electricity-generation
electricity-generation-from-solar-and-wind-compared-to-coal
electricity-imports-share-demand
electricity-mix-uk
electricity-oil
electricity-prod-source-stacked
electricity-production-by-source
electricity-renewables
electricity-source-wb-stacked
electronic-waste-recycling-rate
elite-consultations-score
emission-factors-food-transport
emissions-from-food
emissions-of-air-pollutants
emissions-of-air-pollutants-oecd
emissions-of-particulate-matter
emissions-weighted-carbon-price
employed-fisheries-aquaculture
employed-fisheries-aquaculture-time
employment-discrimination-bans-lgbt
employment-discrimination-lgbt-equaldex
employment-in-agri-vs-urban-pop
employment-in-the-coal-industry-in-the-united-kingdom
employment-to-population-ratio-men-vs-women
endemic-amphibian-species-by-country
endemic-bird-species-by-country
endemic-freshwater-crab-species
endemic-mammal-species-by-country
endemic-reef-forming-coral-species
endemic-shark-and-ray-species
energy-consumption-by-source-and-country
energy-efficiency-of-meat-and-dairy-production
energy-embedded-traded-goods
energy-imports-and-exports-energy-use
energy-intensity
energy-intensity-by-sector
energy-intensity-of-economies
energy-intensity-transport
energy-intensity-vs-gdp
energy-mineral-prices
energy-use-gdp-decoupling
energy-use-per-capita-vs-co2-emissions-per-capita
energy-use-per-capita-vs-gdp-per-capita
energy-use-per-person-vs-gdp-per-capita
engaged-society-score
england-covid-19-mortality-rate-by-vaccination-status
englands-economy-over-the-long-run-gdp-per-capita-vs-population
englands-economy-over-the-long-run-gdp-vs-population
environmental-footprint-milks
equal-access-to-power-index
equal-authority-over-assets-during-marriage
equality-of-civil-liberties-across-social-groups-score
equality-of-political-power-across-social-groups-score
equal-resource-distribution-index
equal-rights-protection-index
estimated-destroyable-area-by-nuclear-weapons-deliverable-in-first-strike
estimated-historical-literacy-rates
estimated-megatons-of-nuclear-weapons-deliverable-in-first-strike
estimated-nuclear-warheads-deliverable-in-first-strike
estimated-prevalence-vs-burden-mental-illnesses
european-overseas-colonies-and-their-colonizers
european-overseas-colonies-and-their-last-colonizer
european-overseas-colonies-by-colonizer
eutrophying-emissions-kcal
eutrophying-emissions-per-kg-poore
eutrophying-emissions-protein
evolution-of-happiness-inequality-within-countries-during-periods-of-uninterrupted-economic-growth
exceptions-to-the-legal-age-of-marriage
excess-deaths-cumulative-economist-single-entity
excess-deaths-cumulative-economist-who
excess-deaths-cumulative-who
excess-deaths-daily-economist-single-entity
excess-nitrogen
excess-nitrogen-per-hectare
excess-phosphorous
excess-phosphorous-per-hectare
excess-skin-cancer-cases-due-to-ozone-depletion
exclusive-breastfeeding-rate
executive-corruption-index
expected-years-of-living-with-disability-or-disease-burden
expected-years-of-schooling
expected-years-of-schooling-males-vs-females
expected-years-of-schooling-vs-share-in-extreme-poverty
expenditure-on-cultural-and-natural-heritage-per-capita
experienced-calmness-a-lot-of-the-day-yesterday-by-age
experienced-calmness-a-lot-of-the-day-yesterday-by-gender
exponential-growth-of-computation-in-the-training-of-notable-ai-systems
exponential-growth-of-datapoints-used-to-train-notable-ai-systems
exponential-growth-of-parameters-in-notable-ai-systems
exported-deforestation
export-of-environmentally-sound-technologies
exports-of-goods-and-services-constant-2010-us
extensively-drug-resistant-tuberculosis
extent-of-extensive-agriculture
extent-of-foraging
extent-of-intensive-agriculture
extent-of-pastoralism
external-balance-on-goods-and-services-as-a-percent-of-gdp
external-debt-as-a-share-of-gni
extinct-species-since-1500
extremely-important-fund-research-anxiety-depression-vs-gdp-per-capita
extreme-one-day-precipitation-usa
extreme-poverty-headcount-ratio-vs-life-expectancy-at-birth
extreme-poverty-vs-child-mortality
extreme-poverty-vs-prevalence-of-underweight-children
facilitate-orderly-safe-migration
fao-projections-of-arable-land-to-2050
farmed-crustaceans
farmed-fish-killed
farm-size-change
fatal-airliner-accidents-hijacking-incidents
fatal-airliner-accidents-per-million-flights
fatal-occupational-injuries-among-employees
feed-required-to-produce-one-kilogram-of-meat-or-dairy-product
female-and-male-life-expectancy-at-birth-in-years
female-employment-to-population-ratio
female-employment-to-population-ratio-latest-vs-1980
female-employment-vs-public-spending-on-family-benefits-oecd
female-genital-mutilation-prevalence
female-homicide-rate
female-homicide-victims
female-labor-force-by-age
female-labor-force-participation-oecd
female-labor-force-participation-rates
female-labor-force-participation-rates-by-family-benefits-public-spending
female-labor-force-participation-rates-by-national-per-capita-income
female-labor-force-participation-rates-latest-vs-1980
female-labor-force-participation-rates-slopes
female-minus-male-life-expectancy-vs-non-communicable-disease-death-rates
female-population-by-age-group
female-share-of-low-pay-earners
female-to-male-life-expectancy-ratio
female-to-male-ratio-of-time-devoted-to-unpaid-care-work
fertility-and-female-labor-force-participation
fertility-and-wanted-fertility
fertility-rate-by-age-group
fertility-rate-vs-mean-years-of-schooling
fertility-rate-vs-share-of-women-between-25-and-29-years-old-with-no-education
fertility-rate-vs-the-share-living-in-extreme-poverty
fertility-rate-with-projections
fertility-vs-child-mortality
fertility-vs-contraception
fertility-vs-unmet-contraception
fertilizer-application-rates-over-the-long-run
fertilizer-consumption-per-hectare-vs-gdp-per-capita
fertilizer-exports-russia-ukraine
fertilizer-per-capita
fertilizer-per-hectare
fertilizer-production-by-nutrient-type-npk
fertilizer-total-use
fertilizer-use-in-kg-per-hectare-of-arable-land
fertilizer-use-nutrient
fertilizer-use-per-hectare-of-cropland
financial-contributions-toward-polio-eradication
fire-death-rates
fire-deaths-by-age
fish-and-seafood-consumption-per-capita
fish-catch-by-fishing-sector
fish-catch-gear-type
fish-catch-region
fish-catch-uk
fish-consumption-vs-gdp-per-capita
fish-discard-rates-gear
fish-discards
fish-discards-gear
fishing-pressure-by-region
fishing-pressure-by-taxa
fish-landings-and-discards
fish-seafood-production
fish-species-threatened
fish-stocks-by-region
fish-stocks-taxa
fish-stocks-within-sustainable-levels
five-year-net-cancer-survival-rates-by-sex
five-year-survival-rate-of-cancers-among-men-in-england
five-year-survival-rates-by-cancer-type
fixed-telephone-subscriptions-per-100-people
flu-vaccines-older-people-recommendation
food-emissions-life-cycle
food-emissions-production-supply-chain
food-emissions-supply-chain
food-exports-ukraine-russia
food-loss-postharvest-by-region
food-miles-by-transport
food-production-ukraine-russia
food-share-total-emissions
food-supply-vs-life-expectancy
food-transport-emissions
food-waste-per-capita
foreign-aid-and-investments-given
foreign-aid-and-investments-received
foreign-aid-given-as-a-share-of-national-income
foreign-aid-given-as-grants-and-concessional-loans
foreign-aid-given-by-sector
foreign-aid-given-by-sector-per-capita
foreign-aid-given-for-emergencies-and-longer-term-development
foreign-aid-given-for-emergencies-and-longer-term-development-per-capita
foreign-aid-given-for-social-infrastructure-and-services
foreign-aid-given-for-social-infrastructure-and-services-per-capita
foreign-aid-given-grant-equivalents
foreign-aid-given-net
foreign-aid-given-net-disbursements-vs-grant-equivalents
foreign-aid-given-net-flows-vs-grant-equivalents-line
foreign-aid-given-per-capita
foreign-aid-given-per-capita-vs-gdp-per-capita
foreign-aid-given-to-donor-countries
foreign-aid-given-to-donor-countries-share
foreign-aid-given-to-least-developed-countries-as-a-share-of-donors-national-income
foreign-aid-received-as-a-share-of-national-income-net
foreign-aid-received-as-grants-and-concessional-loans
foreign-aid-received-by-income-group
foreign-aid-received-net
foreign-aid-received-per-capita
foreign-aid-received-per-capita-vs-gdp-per-capita
foreign-direct-investment-net-inflows-as-share-of-gdp
foreign-direct-investment-net-outflows-as-share-of-gdp
foreign-guests-in-hotels-and-similar-establishments
foreign-policy-free-from-interference-of-other-states-score
forest-area-as-share-of-land-area
forest-area-km
forest-area-net-change-rate
forest-area-primary-planted
forest-transition-phase
forms-of-homelessness-included-in-available-statistics
fossil-electricity-per-capita
fossil-fuel-cons-per-capita
fossil-fuel-consumption-by-fuel-type
fossil-fuel-consumption-by-type
fossil-fuel-consumption-per-capita
fossil-fuel-price-index
fossil-fuel-primary-energy
fossil-fuel-production
fossil-fuel-production-over-the-long-term
fossil-fuel-production-per-capita
fossil-fuels-per-capita
fossil-fuels-share-energy
fossil-fuel-subsidies
fossil-fuel-subsidies-gdp
fossil-fuel-subsidies-per-capita
fraction-of-countries-with-available-data-on-deaths-from-suicides-by-income-group
free-and-fair-elections-index
free-and-fair-elections-row
free-countries-fh
freedom-of-association-index
freedom-of-association-score-bti
freedom-of-expression-index
freedom-of-expression-score-bti
freedom-score-fh
free-fair-elections-bti
frequency-north-atlantic-hurricanes
freshwater-use-by-aggregated-region
freshwater-use-seafood
freshwater-withdrawals-as-a-share-of-internal-resources
freshwater-withdrawals-per-1000kcal
friends-family-anxious-depressed
fuel-efficiency-new-vehicles
full-democracy-lexical
functioning-government-index-eiu
funding-for-trachoma
fur-farming-ban
fur-trading-ban
future-life-expectancy-projections
gamma-camera-or-nuclear-medicine-availability
gap-in-gdp-per-hour-worked-with-respect-to-the-united-states
gas-consumption-by-country
gas-electricity-per-capita
gas-prod-per-capita
gas-production-by-country
gas-share-energy
gavi-supported-countries
gdp-per-capita-maddison-project-database
gdp-per-capita-prados-de-la-escosura
gdp-per-capita-vs-electoral-democracy-index
gdp-per-capita-vs-staff-compensation-as-share-of-total-expenditure-in-primary-public-education
gdp-vs-happiness
gdp-vs-manufacturing-gdp
gender-affirming-care
gender-assignment-surgeries-on-children-banned
gender-development-index
gender-development-index-groups
gender-development-index-vs-gdp-per-capita
gender-development-index-vs-human-development-index
gender-gap-education-levels
gender-gap-in-average-wages-2000-vs-2015
gender-gap-in-average-wages-ilo
gender-gap-in-hourly-wages-vs-ratio-of-female-to-male-labor-force-participation
gender-gap-in-life-expectancy-by-age-group
gender-inequality-index-from-the-human-development-report
gender-marker-can-be-legally-changed
gender-of-chief-executive
gender-of-the-head-of-government
gender-of-the-head-of-state
gender-ratio-in-life-expectancy-at-birth
gender-ratios-for-mean-years-of-schooling
gender-wage-gap-oecd
gender-wage-gap-vs-gdp-per-capita
gender-wage-gap-vs-gdp-per-capita-income-groups
genuine-saving-and-gdp-per-capita-in-international-dollars
genuine-savings-per-capita-in-international-dollars-1900-2000
ghg-emissions-by-gas
ghg-emissions-by-sector
ghg-emissions-by-sector-stacked
ghg-emissions-by-world-region
ghg-emissions-plastic-stage
ghg-emissions-seafood
ghg-kcal-poore
ghg-per-kg-poore
ghg-per-protein-poore
gini-coefficient-after-vs-before-tax-wb-scatter
gini-coefficient-of-lifespan-inequality-by-sex
gini-coefficient-of-lifespan-inequality-in-females
gini-coefficient-of-lifespan-inequality-in-males
girls-and-boys-of-primary-school-age-who-are-out-of-school
girls-and-boys-who-are-out-of-school-wb
global-agricultural-land-use-by-major-crop-type
global-agri-productivity-growth
global-alien-species-first-record-database
global-antimicrobial-resistance-and-use-surveillance-system-glass-by-pathogen
global-aquaculture-wild-fish-feed
global-average-gdp-per-capita-over-the-long-run
global-case-numbers-of-infectious-diseases
global-change-over-the-last-50-years
global-child-deaths-by-cause
global-child-mortality-timeseries
global-co2-concentration
global-cropland
global-crop-production-by-farm-size
global-death-rate-in-violent-political-conflicts-over-the-long-run
global-deaths-by-syndrome-and-antimicrobial-resistance
global-deaths-from-infections-attributable-to-antimicrobial-resistance
global-deaths-in-violent-political-conflicts-over-the-long-run
global-energy-consumption-source
global-energy-substitution
global-fatalities-from-aviation-accidents-and-hijackings
global-first-records-of-established-alien-species
global-fishery-catch-by-sector
global-food-loss-index
global-food-waste-by-region
global-forestry-area-1958-2014
global-fossil-fuel-consumption
global-freshwater-use-over-the-long-run
global-gdp-over-the-long-run
global-hidden-hunger-index-in-pre-school-children
global-hunger-index
global-hunger-index-vs-gdp-per-capita
global-hydro-consumption
global-incidence-of-child-labor-2
global-incidence-of-child-labour
global-incidence-of-child-labour-by-age-groups
global-investment-in-generative-ai
globalization-over-5-centuries
globalization-over-5-centuries-km
global-land-use-since-10000bc
global-living-planet-index
global-malaria-deaths-by-world-region
global-marine-protected-area
global-meat-production
global-meat-production-by-livestock-type
global-meat-projections-to-2050
global-methane-concentrations
global-mine-production-minerals
global-nitrous-oxide-concentration
global-number-of-missing-women
global-pasture
global-peak-agricultural-land
global-precipitation-anomaly
global-prevalence-of-zinc-deficiency
global-primary-energy
global-primary-energy-share-inc-biomass
global-smallpox-cases
global-temperature-anomalies-by-el-nino-la-nina
global-temperature-anomalies-by-el-nino-la-nina-and-month
global-temperature-anomalies-by-month
global-vaccination-coverage
global-views-ai-impact-society-next-20-years-by-demographic-group
global-views-safety-self-driving-car-by-demographic-group
global-warming-by-gas-and-source
global-warming-fossil
global-warming-land
global-whale-biomass
gold-production
good-cholesterol-levels-age-standardized
government-effectiveness-vs-electoral-democracy-index
government-expenditure-on-pre-primary-education-as-share-of-gdp
government-expenditure-on-primary-education-as-share-of-gdp
government-expenditure-on-secondary-education-as-share-of-gdp
government-expenditure-on-tertiary-education-as-share-of-gdp
government-expenditure-per-primary-student-vs-gdp-per-capita
government-expenditure-vs-gdp
government-procurement-share-gdp
government-revenues-as-a-share-of-gdp-imf
government-revenues-as-a-share-of-gdp-world-bank
government-revenues-national-income
government-spending-by-function
government-spending-by-function-as-share-of-gdp-across-countries
government-spending-by-function-as-share-of-gdp-across-time
government-spending-vs-gdp-per-capita
government-transparency
government-vs-private-aid-by-donor
government-vs-private-aid-by-recipient
gov-procurement-share-gov-expenditure
govt-expenditure-share-budget
gpu-price-performance
graphite-production
grazing-land-use-over-the-long-term
green-climate-gcf-fund-pledges
greenhouse-gas-emissions-from-plastics
gross-enrollment-ratio-in-pre-primary-education
gross-enrollment-ratio-in-primary-education
gross-enrollment-ratio-in-secondary-education
gross-enrollment-ratio-in-tertiary-education
gross-national-income-per-capita-males-vs-females
gross-national-income-per-capita-undp
gross-public-sector-debt-as-a-proportion-of-gdp
groundnuts-yield
h5n1-flu-reported-cases
habitat-loss-25-species
haemophilus-influenzae-b-vaccine-immunization-schedule
happiness-cantril-ladder
happiness-vs-gdp-per-capita-time
happiness-wvs-vs-gallup
haq-by-level-of-healthcare-spending-endpoints
hardware-and-energy-cost-to-train-notable-ai-systems
hate-crime-protections-lgbt
hazardous-waste-generated-per-capita
hdi-male-vs-female
hdi-vs-augmented-hdi
healthcare-access-quality-un
healthcare-expenditure-vs-gdp
health-coverage-vs-gdp-per-capita-simple
health-expenditure-and-financing-per-capita
health-expenditure-government-expenditure
health-insurance-coverage-in-the-us
health-protection-coverage
health-provider-absence-rate
health-spending-per-person-by-source
healthy-life-expectancy-and-years-lived-with-disability
healthy-life-expectancy-at-birth
healthy-life-expectancy-vs-health-expenditure-per-capita
hearing-loss-by-age-group
heat-death-rate-vs-co2
heat-deaths-vs-projected-death-rates
heat-wave-index-usa
hepatitis-b-birth-dose-vaccine-immunization-schedule
hepatitis-b-deaths-by-type-of-disease
hepatitis-b-incidence-sdgs
hepatitis-b-number-of-deaths
hepatitis-b-total-number-of-deaths-by-age-group
hepatitis-b-vaccine-immunization-schedule
hepatitis-c-deaths-by-type-of-disease
hepatitis-c-number-of-deaths
hepatitis-c-total-number-of-deaths-by-age-group
hepatitis-death-rate
hepb3-number-unvaccinated
hib3-number-unvaccinated
hib-vaccine
hidden-hunger-index-vs-extreme-poverty
hidden-hunger-index-vs-gdp-per-capita
hidden-hunger-index-vs-share-of-energy-supply-from-cereals-roots-and-tubers
high-summer-temp-usa
historical-cost-of-computer-memory-and-storage
historical-death-rates-from-each-cause-category-in-france
historical-gov-spending-gdp
historical-literacy-in-england-by-sex
historical-share-of-population-living-on-less-than-5-per-day
historical-share-of-population-living-on-less-than-per-day2
hivaids-deaths-and-averted-due-to-art
hiv-funding-and-future-requirements
hiv-funding-by-region
homelessness-by-gender-point-in-time-count
homelessness-rate-flow-count
homelessness-rate-point-in-time-count
homicide-deaths-by-age
homicide-rate
homicide-rate-1990-vs-2020
homicide-rate-across-sources
homicide-rate-age-standardized
homicide-rate-by-age
homicide-rate-by-age-of-the-victim
homicide-rate-by-sex
homicide-rate-ghe
homicide-rate-ihme-vs-unodc
homicide-rate-ihme-vs-who-mort-db
homicide-rate-in-15--to-49-year-olds
homicide-rates-across-western-europe
homicide-rates-from-firearms
homicide-rate-unodc
homicide-rate-vs-gdp-pc
homicide-rate-where-the-perpetrator-is-an-intimate-partner
homicide-rate-who-age-standardized
homicide-rate-who-mortality-database
homicide-rate-who-vs-unodc
homicides-by-firearm
homicides-by-sex-of-the-victim
homicidesghe
homicides-ihme
homicides-unodc
homicides-whomd
hospital-beds-per-1000-people
hourly-earnings-male-vs-female
hours-per-week-spent-in-market-and-non-market-work-by-sex-united-states
household-air-pollution-deaths-by-region
households-air-conditioning
household-vs-outdoor-air-pollution-death-rates
housing-discrimination-lgbt-equaldex
how-important-family-is-to-people-in-life
how-important-friends-are-to-people-in-life
how-important-leisure-is-to-people-in-life
how-important-politics-is-in-your-life
how-important-religion-is-in-your-life
how-important-work-is-to-people-in-life
how-much-we-think-we-spend-on-healthcare-vs-how-much-we-actually-do
hubberts-peak-vs-actual-oil-production-in-the-united-states
human-capital-index-in-2018
human-development-index
human-development-index-groups
human-development-index-vs-corruption-perception-index
human-development-index-vs-gdp-per-capita
human-development-index-vs-mean-male-height
human-papillomavirus-vaccine-immunization-schedule
human-rights-index-vdem
human-rights-index-vs-electoral-democracy-index
human-rights-index-vs-gdp-per-capita
human-trafficking-victims
human-trafficking-victims-under-18-years-old-male-vs-female
hurricane-landfalls-us
hurricane-track-error
hydro-consumption-by-region
hydro-electricity-per-capita
hydropower-consumption
hydro-share-energy
hypertension-adults-30-79
hypothetical-global-meat-demand
hypothetical-land-animals-slaughtered
hypothetical-number-of-deaths-from-energy-production
icd-code-version-used-to-classify-causes-of-death
ice-sheet-mass-balance
ict-adoption
ict-adoption-per-100-people
ihr-core-capacity-index-sdgs
immunization-coverage-against-diphtheria-tetanus-and-pertussis-dtp3-vs-gdp-per-capita
immunization-hepb3-of-one-year-old-children
immunization-measles-vs-vaccine-safety
implementation-of-integrated-water-resource-management
implementation-of-tools-to-monitor-economic-and-environmental-tourism
implementation-of-unclos
importance-government-funding-research-anxiety-depression
importance-science-treating-anxiety-depression
imported-deforestation
import-of-environmentally-sound-technologies
imports-of-goods-and-services-constant-2010-us
imports-of-ppe-related-products
imports-of-ppe-related-products-per-capita
improved-sanitation-facilities-vs-gdp-per-capita
improved-water-sources-vs-gdp-per-capita
inactivated-poliovirus-vaccine-immunization-schedule
incidence-and-prevalence-of-rabies
incidence-bribes-firms-2013
incidence-of-child-labor-in-italy
incidence-of-child-labor-in-the-uk
incidence-of-child-labor-in-the-united-states
incidence-of-child-labor-in-the-united-states-1890-1930
incidence-of-child-labour
incidence-of-child-labour-boys-vs-girls
incidence-of-child-labour-vs-gdp-per-capita
incidence-of-meningitis
incidence-of-tuberculosis
incidence-of-venomous-animal-contact
incidence-rate-of-cardiovascular-disease
inciting-hatred-laws-lgbt
income-inequality-atkinson-index-undp
income-taxes-share-of-revenue-europe
increase-male-vs-female-height
index-of-cereal-production-yield-and-land-use
index-of-us-maternal-mortality-and-female-labor-force-participation-flfp
indian-rhinos
individual-liberties-and-equality-before-the-law-index
indoor-pollution-death-rates-clean-fuels
indoor-pollution-deaths-1990-2017
industrial-robots-annual-installations-total-operational
industrial-water-as-a-share-of-total-water-withdrawals
industrial-water-withdrawal
industry-share-of-total-emplyoment
inequality-adjusted-hdi-vs-human-development-index
inequality-adjusted-human-development-index
inequality-adjusted-human-development-index-vs-gdp-per-capita
inequality-in-education
inequality-in-life-expectancy
inequality-in-life-expectancy-vs-health-expenditure-per-capita
infant-death-rates-by-cause-by-sex
infant-deaths
infant-mortality
infant-mortality-by-sex
infant-mortality-rate
infant-mortality-rates
infant-mortality-rates-uk
infant-mortality-rate-wdi
infant-mortality-vaccines
infant-mortality-vs-prenatal-care
infants-pre-term-share
infectious-and-parasitic-diseases-death-rate-who-mdb
infectious-disease-death-rates
infectious-disease-death-rates-gbd
influenza-vaccination-rate-elderly-oecd
influenza-vaccination-rate-elderly-who-unicef
informal-employment-by-sex
informal-employment-of-total-non-agricultural-employment
injuries-from-terrorist-attacks
insecticide-use
installed-geothermal-capacity
installed-global-renewable-energy-capacity-by-technology
installed-solar-pv-capacity
intercontinental-trade-per-capita-1500-1800
internal-renewable-freshwater-resources-by-region
international-arrivals-for-personal-vs-business-and-professional-reasons
international-finance-clean-energy
international-same-day-arrivals
international-same-day-visitors-per-1000-people
international-tourist-arrivals-by-region-of-origin
international-tourist-departures
international-tourist-departures-per-1000
international-tourist-trips
international-tourist-trips-by-destination-region
international-tourist-trips-per-1000-people
international-trips-for-business-and-professional-reasons
international-trips-for-personal-reasons
interpersonal-trust-in-europe
interpersonal-trust-in-the-us
interpersonal-trust-measured-in-different-surveys
interpersonal-trust-vs-income-inequality
intersex-infant-surgery
interventions-for-substance-use-disorders
interventions-ntds-sdgs
investment-in-renewable-energy-by-technology
ipv1-number-unvaccinated
ipv-vaccine-coverage
is-antibiotic-use-in-livestock-above-global-guidelines
iwc-members
javan-rhinos
job-seeker-job-search-pew
joint-adoptions-by-same-sex-partners
joint-adoptions-same-sex-partners-equaldex
judicial-constraints-on-the-executive-index
judicial-corruption-score
justified-political-positions-score
kaya-identity-co2
key-crop-yields
key-features-of-electoral-democracy
key-features-of-human-rights
key-features-of-liberal-democracy
key-features-of-womens-political-empowerment
key-media-freedoms
kilograms-meat-per-animal
labor-cost-ratio-and-attainment-levels-2009-or-latest-available-year
labor-force-participation-rate-female-of-female-population-ages-15-modeled-ilo-estimate-vs-gdp-per-capita
labor-force-participation-rates-for-women-ages-15-24-2020-vs-1980
labor-productivity-agriculture-sweden
labor-productivity-per-hour-pennworldtable
labor-share-of-gdp
labour-force-participation-younger-vs-older-women
land-animals-slaughtered-for-meat
land-area-hectares
land-area-km
land-area-per-crop-type
landline-internet-subscriptions
landline-internet-subscriptions-by-speed
landline-internet-subscriptions-per-100-people-by-speed
landline-phone-subscriptions
land-natural-share
land-ownership-men-vs-women
land-sparing-by-crop
land-use
land-use-agriculture-longterm
land-use-for-vegetable-oil-crops
land-use-kcal-poore
land-use-over-the-long-term
land-use-palm-oil
land-use-per-kg-poore
land-use-protein-poore
land-use-seafood
land-use-vs-yield-change-in-cereal-production
large-household-expenditures-health
large-oil-spills-decadal
law-mandate-nondiscrimination-hiring
laws-antimicrobials-aquatic
laws-antimicrobials-livestock
laws-on-child-marriage
laying-hens-cages-and-cage-free
leading-broad-cause-of-death
leading-cancer-types-causing-death-in-men
leading-cancer-types-causing-death-in-women
leading-cause-of-child-mortality-among-children-under-five
leading-cause-of-death
lead-paint-over-10000ppm
lead-paint-over-600ppm
learning-adjusted-years-of-schooling-gender-scatter
learning-adjusted-years-of-schooling-marimekko
learning-adjusted-years-of-schooling-vs-electoral-democracy-index
learning-adjusted-years-of-school-lays
learning-outcomes-vs-gdp-per-capita
legal-frameworks-addressing-gender-equality-in-employment-and-economic-benefits
legal-frameworks-gender-equality-within-marriage-and-family
legal-frameworks-regarding-violence-against-women
legally-recognized-rights-to-land
legal-status-of-same-sex-sexual-acts
legislation-domestic-violence
legislation-on-sexual-harassment-in-employment
legislative-constraints-on-the-executive-index
legislative-corruption-score
lettuce-yields
levelized-cost-of-energy
level-of-national-compliance-with-labor-rights
lgb-military-velasco
lgbt-legal-equality-index
lgbt-military-equaldex
lgbt-rights-index
liberal-democracy-index
liberal-democracy-row
liberal-political-institutions-index
liberal-political-institutions-row
life-expectancy
life-expectancy-at-age-15
life-expectancy-at-birth-including-the-un-projections
life-expectancy-at-birth-oecd
life-expectancy-at-birth-source-comparison
life-expectancy-at-birth-who-gho
life-expectancy-at-different-ages
life-expectancy-hmd-unwpp
life-expectancy-marimekko
life-expectancy-of-women-vs-life-expectancy-of-men
life-expectancy-prados-de-la-escosura
life-expectancy-un-vs-gdp-per-capita-wb
life-expectancy-unwpp
life-expectancy-versus-gini-lifespan-inequality
life-expectancy-vs-electoral-democracy-index
life-expectancy-vs-expected-years-lived-with-disability
life-expectancy-vs-gdp-per-capita
life-expectancy-vs-healthcare-expenditure
life-expectancy-vs-health-expenditure
life-expectation-at-birth-by-sex
life-satisfaction-vs-child-mortality
life-satisfaction-vs-co-emissions-per-capita
life-satisfaction-vs-life-expectancy
lighting-sources-uk
literacy-by-years-of-schooling-us-1947
literacy-rate-adult-female-dhs-surveys-vs-unesco
literacy-rate-adult-male-dhs-surveys-vs-unesco
literacy-rate-adults
literacy-rate-adult-total-dhs-surveys-vs-unesco
literacy-rate-of-young-men-and-women
literacy-rate-of-young-men-and-women-line
literacy-rates-of-younger-vs-older-population
literacy-rate-source-type
literacy-rates-vs-average-years-of-schooling
literacy-rate-vs-gdp-per-capita
literate-and-illiterate-world-population
lithium-production
liver-cancer-death-rate
liver-cancer-incidence-rate-by-risk-factor
lives-saved-vaccines
lives-saved-vaccines-region
livestock-counts
living-languages
living-planet-index-by-region
living-planet-index-comparison
local-gov-disaster-strategies
local-govts-risk-reduction
local-guests-in-hotels-and-similar-establishments
locations-of-ongoing-armed-conflicts
long-run-air-pollution
long-run-birth-rate
long-run-methane-concentration
long-term-cod-catch
long-term-energy-transitions
long-term-urban-population-region
low-carbon-elec-per-capita
low-carbon-electricity
low-carbon-energy-consumption
low-carbon-share-energy
low-earth-orbits-objects
lower-secondary-completion-rate-adjusted-gender-parity-index
low-winter-temps-usa
lung-cancer-death-rates-males
lung-cancer-deaths-men-women
lung-cancer-deaths-per-100000-by-sex-1950-2002
lymphatic-filariasis-treatment-coverage
machinery-per-agricultural-land
magnetic-resonance-imaging-mri-units-availability
maize-attainable-yield
maize-exports-ukraine-russia-perspective
maize-production
maize-yield-gap
maize-yields
major-causes-of-child-deaths
male-female-ratio-suicides-rates
male-high-blood-pressure
male-homicide-rate
male-homicide-victims
male-population-by-age-group
male-to-female-height-ratio
male-to-female-ratio-of-high-school-courses-in-math-and-science
male-vs-female-informal-employment-as-share-of-total-employment
male-vs-female-suicide-who
malnutrition-death-rates
malnutrition-death-rate-vs-gdp-per-capita
mandatory-childhood-vaccination
manufacturing-share-of-total-employment
manuscript-production-century
map-gender-equal-inheritance
marine-protected-areas
market-share-logic-chip-production-manufacturing-stage
market-share-of-household-salt-with-iodine-fortification-europe
marriage-for-same-sex-partners-velasco
marriage-rate-per-1000-inhabitants
marriage-rates-in-1990-vs-2020
marriage-same-sex-partners-equaldex
marriages-ending-divorce-uk
marriages-uk-ended-in-divorce
mass-us-glaciers
material-footprint-per-capita
material-footprint-per-unit-of-gdp
materials-low-carbon-electricity
maternal-mortality
maternal-mortality-vs-female-labor-force-participation
maternal-mortality-vs-fertility
maternal-mortality-vs-neonatal-mortality
maximum-life-expectancy-sex-female
maximum-marginal-tax-rates-on-individual-income
mcv2-vaccine-immunization-schedule
mean-height-males-vs-females
mean-years-of-schooling-female
mean-years-of-schooling-long-run
mean-years-of-schooling-male
measles-cases-and-death
measles-cases-and-death-rate
measles-coverage-vs-cases-worldwide
measles-number-unvaccinated
measles-prevalence-vaccine-attitudes
meat-consumption-vs-gdp-per-capita
meat-production-tonnes
meat-supply-per-person
media-corruption-score
median-age
median-age-vs-births-per-woman
medical-doctors-per-1000-people-vs-gdp-per-capita
medium-high-level-implementation-of-sustainable-public-procurement
men-experienced-sexual-violence-by-age-18
meningitis-death-rates-children-under-5
mens-life-expectancy-at-birth
men-survival-to-age-65
mental-and-substance-use-as-share-of-disease
mental-health-as-risk-for-drug-dependency
mental-health-units-in-general-hospitals
mental-illnesses-prevalence
mental-illness-estimated-cases
men-women-friends-family-anxious-depressed
merchandise-exports-by-continent
merchandise-exports-gdp-cepii
merchandise-imports-gdp-cepii
methane-emissions
methane-emissions-agriculture
methane-emissions-by-sector
migrant-recruitment-costs
migrant-stock-share
migrant-stock-total
military-expenditure-as-a-share-of-government-spending
military-personnel
military-personnel-as-a-share-of-total-population
military-spending-as-a-share-of-gdp-gmsd
military-spending-as-a-share-of-gdp-sipri
military-spending-gmsd
military-spending-per-armed-forces-personnel
military-spending-per-military-personnel
military-spending-sipri
milk-production-tonnes
milk-yields-per-animal
millet-yield
minimum-requirement-calories
mining-electricity-sources-including-gas
mining-requirements-electricity-sources
mismanaged-plastic-waste-per-capita
missing-female-births-and-excess-mortality
mobile-cellular-subscriptions-by-country
mobile-cellular-subscriptions-per-100-people
mobile-landline-subscriptions
mobile-money-account-usage
modal-age-at-death-in-adults
modeled-female-employment-to-population-ratio
mode-of-reporting-literacy-rates
modern-contraceptive-prevalence-vs-gdp-per-capita
modern-renewable-energy-consumption
modern-renewable-prod
money-committed-to-public-private-partnerships-for-infrastructure
money-sent-or-brought-back-by-migrants-as-a-share-of-gdp
monthly-average-surface-temperatures-by-decade
monthly-average-surface-temperatures-by-year
monthly-birth-rate-per-day
monthly-co2-emissions-from-international-and-domestic-flights
monthly-co2-emissions-from-international-aviation
monthly-ocean-heat-2000m
monthly-sea-ice-extent-in-the-antarctic
monthly-sea-ice-extent-in-the-antarctic-decadal-average
monthly-sea-ice-extent-in-the-arctic
monthly-sea-ice-extent-in-the-arctic-decadal-average
monthly-surface-temperature-anomalies-by-decade
monthly-surface-temperature-anomalies-by-year
monthly-temperature-anomalies
monthly-upper-ocean-heat
mortality-from-ncds-gender
mortality-from-ncds-sdgs
mortality-neonatal-asphyxia-and-trauma
mortality-rate-attributable-to-wash
mortality-rates-age-25-by-sex
mortality-rates-age-65-by-sex
most-common-waste-rivers-oceans
mountain-green-cover-index
multidrug-resistant-tuberculosis-without-extensive-drug-resistance
multi-party-elections-hoe-row
multi-party-elections-legislature-row
multi-party-elections-row
mumps-cases-and-deaths-in-the-united-states
mumps-vaccine-immunization-schedule
municipal-waste-recycled
municipal-waste-recycling-rate
municipal-water-as-a-share-of-total-water-withdrawals
municipal-water-withdrawal
nasa-annual-budget
national-average-learning-outcomes-vs-government-expenditure-per-primary-student
national-biodiversity-strategy-align-with-aichi-target-9
nationally-determined-contributions
national-progress-towards-aichi-biodiversity-target-2
national-statistical-legislation
national-system-to-monitor-antimicrobials-usage-for-human-medicine
national-system-to-monitor-spread-of-antimicrobial-resistance-in-humans
natural-disaster-death-rates
natural-disaster-deaths-ihme
natural-disasters-by-decadal-size
natural-disasters-by-type
natural-disasters-by-yearly-impact
natural-gas-consumption-by-region
natural-gas-prices
natural-gas-production-by-region-terawatt-hours-twh
natural-gas-proved-reserves
natural-population-growth
natural-resource-rents
near-earth-asteroids-discovered-over-time
neonatal-deaths-by-cause
neonatal-deaths-from-bloodstream-infections-attributed-to-antimicrobial-resistance
neonatal-deaths-from-infections-attributed-to-antimicrobial-resistance-by-syndrome
neonatal-infant-and-child-deaths
neonatal-mortality-ihme
neonatal-mortality-rate-gho
neonatal-mortality-vs-births-attended-by-staff
neonatal-mortality-wdi
neonatal-sepsis-and-infection-death-rate-in-infants
net-deforestation-in-trade
net-electricity-imports
net-enrollment-rate-pre-primary
net-enrollment-rate-primary-gender-parity-index-gpi
net-food-trade-as-a-share-of-domestic-supply
net-oda-to-medical-research
net-official-development-assistance-and-aid-received
net-zero-targets
net-zero-target-set
new-books-per-million
new-infections-with-tetanus
newly-funded-artificial-intelligence-companies
new-neonatal-tetanus-cases-per-million
new-passenger-vehicles-type
new-reported-cases-tetanus
news-coverage-of-disasters
new-vehicles-type-area
new-vehicles-type-share
nitrogen-emissions-seafood
nitrogen-fertilizer-application-per-hectare-of-cropland
nitrogen-inputs-per-hectare
nitrogen-output-vs-nitrogen-input-to-agriculture
nitrogen-use-efficiency
nitrous-oxide-agriculture
nitrous-oxide-emissions
nitrous-oxide-emissions-by-sector
nitrous-oxide-long
non-commercial-flight-distance-records
northern-white-rhinos
nuclear-electricity-per-capita
nuclear-energy-generation
nuclear-non-proliferation-treaty
nuclear-primary-energy
nuclear-warhead-inventories
nuclear-warhead-stockpiles
nuclear-warhead-stockpiles-lines
nuclear-weapons-proliferation
number-agri-environmental-policies
number-airline-passengers
number-air-trips-vs-gdp
number-bev-phev-sold
number-child-deaths-malnutrition
number-children-stunted-who
number-children-wasted-who
number-countries-mandatory-vaccination
number-democracies-age-polity
number-electoral-democracies-age
number-electoral-democracies-age-lexical
number-farms-size
number-injured-from-disasters
number-liberal-democracies-age
number-of-accessions-of-plant-genetic-resources-secured-in-conservation-facilities
number-of-armed-conflicts
number-of-asian-elephants
number-of-births-per-year
number-of-child-deaths
number-of-child-deaths-by-the-type-of-congenital-birth-defect
number-of-child-deaths-igme
number-of-child-deaths-unwpp
number-of-children-newly-infected-with-hiv
number-of-children-that-die-from-road-injuries
number-of-children-who-are-underweight
number-of-commercial-bank-branches-per-100000-adults
number-of-countries
number-of-countries-administering-each-major-vaccine
number-of-countries-by-region
number-of-countries-having-implemented-a-vat
number-of-countries-reporting-confirmed-bacterial-infections
number-of-countries-that-approve-of-nuclear-weapons-treaties
number-of-countries-where-armed-conflicts-took-place
number-of-countries-with-a-vaccine-stock-out
number-of-countries-with-basic-statistical-institutions
number-of-countries-with-key-economic-and-social-rights-for-women
number-of-countries-with-primary-data-on-prevalence-of-mental-illnesses-in-the-global-burden-of-disease-study
number-of-deaths
number-of-deaths-by-age-group
number-of-deaths-by-risk-factor
number-of-deaths-from-cervical-cancer
number-of-deaths-from-diarrheal-diseases-by-risk-factor-for-under-5s
number-of-deaths-from-hivaids
number-of-deaths-from-hivaids-who
number-of-deaths-from-pneumonia-in-children-under-5
number-of-deaths-from-rabies-by-world-region
number-of-deaths-from-road-injuries
number-of-deaths-from-suicide-ghe
number-of-deaths-from-tetanus
number-of-deaths-from-tuberculosis-ghe
number-of-deaths-gbd
number-of-deaths-per-year
number-of-deaths-who
number-of-described-species
number-of-estimated-paralytic-polio-cases-by-world-region
number-of-european-overseas-colonies
number-of-european-overseas-colonies-and-colonizers
number-of-european-overseas-colonies-by-region
number-of-farms
number-of-full-democracies-by-age
number-of-hospitals-with-cardiovascular-units-per-million-people
number-of-individuals-employed-in-tourism-related-industries-per-1000-people
number-of-infant-deaths
number-of-infant-deaths-gho
number-of-infant-deaths-ihme
number-of-infant-deaths-unwpp
number-of-infections-tested-for-antibiotic-susceptibility
number-of-internet-users
number-of-interstate-conflicts
number-of-large-scale-ai-systems-released-per-year
number-of-measles-cases
number-of-members-of-united-nations
number-of-natural-disaster-events
number-of-neonatal-deaths-by-region
number-of-neonatal-deaths-igme
number-of-neonatal-deaths-ihme
number-of-new-armed-conflicts
number-of-new-cases-and-deaths-from-cervical-cancer
number-of-new-hiv-child-infections-vs-number-of-infections-averted-due-to-pmtct
number-of-new-state-based-conflicts
number-of-new-tetanus-cases-in-children-under-5
number-of-new-wars
number-of-nuclear-weapons-tests
number-of-one-year-olds
number-of-parties-env-agreements
number-of-patents-through-the-industrial-revolution
number-of-people-employed-in-food-and-beverage-serving-activities-per-1000-population
number-of-people-in-the-world-with-and-without-access-to-improved-water-sources
number-of-people-moderately-or-severely-food-insecure
number-of-people-severely-food-insecure
number-of-people-with-and-without-electricity-access
number-of-people-with-blindness-due-to-each-cause
number-of-people-with-cancer
number-of-people-with-cancer-by-age
number-of-people-with-cancer-by-type
number-of-people-with-mild-or-severe-anemia-from-ntds
number-of-refugees-per-100000
number-of-reported-cholera-deaths
number-of-reported-guinea-worm-dracunculiasis-cases
number-of-reported-road-incidents
number-of-reported-smallpox-cases
number-of-reported-yaws-cases
number-of-rhinos-poached
number-of-severely-food-insecure-people-by-region
number-of-state-based-conflicts
number-of-tanker-spills-by-operation-at-time-of-incident
number-of-tanker-spills-by-primary-cause-of-spill
number-of-transboundary-animal-breeds-which-have-genetic-resources-secured-in-conservation-facilities
number-of-tsunamis
number-of-unique-settlements
number-of-wars-correlates-of-war
number-of-wars-project-mars
number-of-youth-deaths
number-oil-spills
number-outdoor-pollution-deaths-by-age
number-species-evaluated-iucn
number-species-threatened
number-suffering-from-depression-by-region
number-suicide-deaths
number-suicide-deaths-source-comparison
number-undernourished
number-un-peacekeeping-missions
number-using-at-least-basic-sanitation
number-with-autistic-spectrum-disorder
number-with-drug-disorders-by-substance
number-with-drug-use-disorders-country
number-with-mental-health-disorders-by-sex
number-without-access-to-improved-sanitation
number-without-clean-cooking-fuel
number-without-electricity-by-region
number-without-improved-water
number-without-safe-drinking-water
number-with-without-clean-cooking-fuels
numeracy-rate-in-adult-men
numeracy-rate-in-adult-women-sdg
numeracy-skills-of-adults-young-adults-and-adults
numeracy-vs-literacy-skills-of-adults
nurses-and-midwives-per-1000-people
obesity-prevalence-adults-who-gho
ocean-heat-content-upper
ocean-heat-top-2000m
ocean-research-funding
ocean-waste-by-item
oda-for-scholarships
oecd-average-trust-in-governments
oecd-expenditures-on-government-outsourcing-gdp
oecd-female-labour-force-participation-rate-15-64
official-development-assistance-donor-bilateral-multilateral
official-development-assistance-to-least-developed-countries
official-entrance-age-to-compulsory-education
official-entrance-age-to-pre-primary-education
oil-consumption-by-country
oil-consumption-by-region-terawatt-hours-twh
oil-electricity-per-capita
oil-prices-inflation-adjusted
oil-prod-per-capita
oil-production-by-country
oil-production-by-region
oil-proved-reserves
oil-rents-as-a-share-of-gdp
oil-share-energy
oil-yield-by-crop
one-person-households
open-defecation-in-rural-areas-vs-urban-areas
opinions-young-people-climate
orange-yields
organic-agricultural-area
outdoor-pollution-death-rate
outdoor-pollution-deaths-1990-2017
outdoor-pollution-rates-by-age
outdoor-pollution-rate-vs-gdp
out-of-pocket-expenditure-per-capita-on-healthcare
out-of-school-children-of-primary-school-age-by-world-region
overarching-legal-frameworks-regarding-gender-equality
ozone-depleting-substance-consumption
ozone-depleting-substance-emissions
ozone-depleting-substances-index
ozone-o3-concentration-in-ppb
pain-broiler-chickens
pain-levels-hen-systems
palm-oil-imports
palm-oil-production
palm-oil-yields
pancreatic-cancer-death-rate
parameters-vs-training-dataset-size-in-notable-ai-systems-by-researcher-affiliation
parents-same-sex-vs-different-sex
parents-who-agree-with-spanking-to-discipline-a-child
partial-nuclear-test-ban-treaty
participants-in-ongoing-state-based-conflicts-by-region
participation-of-women-in-purchase-decisions-vs-gdp-per-capita
participation-rate-in-formal-and-non-formal-education-and-training
participatory-democracy-index
participatory-political-institutions-index
parties-to-multilateral-agreements-on-hazardous-waste
patent-applications-per-million
patents-ccs
patents-electric-vehicles
patents-energy-storage
patents-filed-for-renewables
patents-for-renewables-by-country
patents-usa-by-category
pcv3-number-unvaccinated
peaceful-and-hostile-relationships-between-states
peaceful-and-hostile-relationships-between-states-no-relationship-included
peak-birth-month
pea-yields
people-asked-for-a-bribe-vs-firms-asked-for-a-bribe
people-joint-adoptions-same-sex-partners-legal
people-living-countries-legalized-sex-marriage
people-living-in-countries-in-which-gender-marker-can-be-legally-changed
people-living-in-countries-in-which-same-sex-sexual-acts-are-legal
people-living-in-countries-that-have-universal-voting-rights
people-living-in-countries-that-sanction-domestic-violence
people-living-in-countries-with-woman-chief-executive
people-living-in-democracies-autocracies
people-living-in-democracies-autocracies-amb-row
people-living-in-democracies-autocracies-bti
people-living-in-democracies-autocracies-lexical
people-living-in-democracies-autocracies-simplified-lexical
people-living-in-democracies-nondemocracies-eiu
people-living-in-democracies-nondemocracies-fh
people-living-in-democracies-nondemocracies-polity
people-living-in-democratizing-autocratizing-countries-ert
people-living-in-democratizing-autocratizing-democracies-autocracies-ert
people-living-in-free-countries-fh
people-living-in-united-nations-member-states
people-practicing-open-defecation-of-population
people-third-gender-recognized
people-treated-for-river-blindness
people-who-report-having-friends-or-relatives-they-can-count-on
people-with-access-to-at-least-basic-drinking-water
people-without-clean-cooking-fuels-region
people-without-electricity-country
per-capita-co2-aviation
per-capita-co2-by-source
per-capita-co2-cement
per-capita-co2-coal
per-capita-co2-domestic-aviation-vs-gdp
per-capita-co2-domestic-aviation-vs-land-area
per-capita-co2-emissions-from-domestic-aviation
per-capita-co2-flaring
per-capita-co2-food-deforestation
per-capita-co2-fuel
per-capita-co2-gas
per-capita-co2-including-land
per-capita-co2-international-aviation
per-capita-co2-international-flights-adjusted
per-capita-co2-oil
per-capita-co2-region
per-capita-co2-sector
per-capita-co2-transport
per-capita-co2-vs-average
per-capita-co-emissions-from-international-flights-tourism-adjusted
per-capita-co-emissions-vs-human-development-index
per-capita-consumption-based-co-emissions-vs-per-capita-energy-consumption
per-capita-egg-consumption-kilograms-per-year
per-capita-electricity-demand
per-capita-electricity-fossil-nuclear-renewables
per-capita-electricity-generation
per-capita-electricity-generation-from-solar-and-wind
per-capita-electricity-generation-vs-gdp-per-capita
per-capita-electricity-source-stacked
per-capita-energy-consumption-from-solar-and-wind
per-capita-energy-source-stacked
per-capita-energy-stacked
per-capita-energy-use
per-capita-fossil-energy-vs-gdp
per-capita-gas
per-capita-ghg-emissions
per-capita-ghg-excl-land-use
per-capita-ghg-sector
per-capita-hydro
per-capita-low-carbon-energy
per-capita-low-carbon-vs-gdp
per-capita-meat-consumption-by-type-kilograms-per-year
per-capita-meat-eu28
per-capita-meat-type
per-capita-meat-usa
per-capita-methane-emissions
per-capita-methane-sector
per-capita-milk-consumption
per-capita-nitrous-oxide
per-capita-nitrous-oxide-sector
per-capita-nuclear
per-capita-ocean-plastic-waste
per-capita-oil
per-capita-renewable-freshwater-resources
per-capita-renewables
per-capita-solar
per-capita-sources-of-protein
per-capita-wind
perceived-comfort-speaking-anxiety-depression
perceived-comfort-speaking-anxiety-depression-vs-talked-to-family-friends-when-had-anxiety-depression
perceived-influence-over-government
perceived-justifiability-of-terrorism-as-a-political-ideological-or-religious-means
perceived-trust-between-people
percentage-change-energy-by-source
percentage-of-americans-who-live-alone-by-age
percentage-of-children-214-who-experience-violent-discipline-at-home
percentage-of-children-in-employment-by-sex
percentage-of-girls-15-to-19-who-report-having-been-victims-of-sexual-abuse
percentage-of-men-18-to-29-who-report-having-been-victims-of-forced-sex-as-children
percentage-of-men-in-the-united-states-who-live-alone-by-age
percentage-of-persons-without-health-insurance-coverage-us
percentage-of-primary-schools-with-access-to-potable-water
percentage-of-primary-schools-with-toilets
percentage-of-teachers-in-lower-secondary-education-who-are-qualified
percentage-of-teachers-in-pre-primary-education-who-are-qualified
percentage-of-teachers-in-primary-education-who-are-qualified
percentage-of-teachers-in-secondary-education-who-are-qualified
percentage-of-teachers-in-upper-secondary-education-who-are-qualified
percentage-of-territory-controlled-by-government
percentage-of-women-18-to-29-who-report-having-been-victims-of-forced-sex-as-children
percentage-of-women-in-the-united-states-who-live-alone-by-age
perception-of-corruption-by-institution
perception-of-the-safety-of-vaccines-vs-vaccine-coverage
period-average-age-of-mothers
period-average-age-of-mothers-birth-order
period-total-fertility-rate
period-versus-cohort-life-expectancy
personal-remittances-oda
pertussis-cases-and-deaths-in-the-united-states
pesticide-breakdown-by-type
pesticide-use-per-hectare-of-cropland
pesticide-use-tonnes
pharmaceutical-personnel-per-1000
phosphate-application-per-hectare-of-cropland
phosphorous-emissions-seafood
phosphorous-inputs-per-hectare
physical-integrity-rights-index-vdem
physical-integrity-rights-score-fariss-kenwick-reuning
physicians-per-1000-people
pig-land-welfare
pig-livestock-count-heads
pigmeat-production-tonnes
pig-production-greenhouse-gas-emissions-vs-cost-to-animal-welfare
pig-yields-meat-per-animal-in-hectograms-100-grams
pisa-mean-performance-on-the-mathematics-scale-by-sex
pisa-mean-performance-on-the-reading-scale-by-sex
pisa-test-score-mean-performance-on-the-mathematics-scale
pisa-test-score-mean-performance-on-the-reading-scale
plastic-fate
plastic-fate-to-2050
plastic-waste-emitted-to-the-ocean
plastic-waste-generation-total
plastic-waste-mismanaged
plastic-waste-per-capita
pm25-air-pollution
pm25-exposure-gdp
pm-exposure-1990-2017
pneumococcal-conjugate-vaccine-immunization-schedule
pneumococcal-vaccination-averted-deaths
pneumonia-and-lower-respiratory-diseases-deaths
pneumonia-careseeking
pneumonia-death-rates-age-standardized
pneumonia-death-rates-in-children-under-5
pneumonia-mortality-by-age
pneumonia-risk-factors
police-officers-per-1000-people
polio-number-unvaccinated
polio-screening-and-testing
polio-vaccine-coverage-of-one-year-olds
polio-vaccine-schedule
political-centralization-index
political-civil-liberties-index
political-corruption-index
political-liberties-lexical
political-opposition-lexical
political-participation-index-bti
political-participation-index-eiu
political-polarization-score
political-regime
political-regime-amb-row
political-regime-bti
political-regime-classification-by-source
political-regime-dem-fh
political-regime-eiu
political-regime-ert
political-regime-ert-within-regimes
political-regime-fh
political-regime-lexical
political-regime-polity
political-rights-rating-fh
political-rights-score-fh
political-social-integration-index-bti
pollution-deaths-from-fossil-fuels
population
population-at-risk-of-trachoma-vs-receiving-treatment
population-by-age-group
population-by-age-group-with-projections
population-by-five-year-age-group
population-by-income-level
population-by-legal-status-of-same-sex-marriage
population-census-brambor
population-census-world-bank
population-covered-by-mobile-network-by-network-capability
population-density
population-density-by-city
population-density-of-the-capital-city
population-density-vs-prosperity
population-growth-rate
population-growth-rate-by-level-of-development
population-growth-rates
population-growth-rate-vs-median-age
population-growth-rate-with-and-without-migration
population-having-attained-at-least-basic-education
population-in-the-largest-city
population-living-in-european-colonies-and-colonizers
population-long-run-with-projections
population-marimekko
population-of-cities-towns-and-villages
population-of-england-millennium
population-regions-with-projections
population-register-implemented
population-requiring-preventive-chemotherapy-for-schistosomiasis
population-requiring-preventive-treatment-for-lymphatic-filariasis
population-requiring-preventive-treatment-for-river-blindness
population-subjected-to-physical-violence
population-subjected-to-sexual-violence-male-vs-female
population-threshold-for-urban-area
population-unwpp
population-using-at-least-basic-drinking-water
population-using-solid-fuels-for-cooking
population-with-un-projections
population-younger-than-15-with-projections
population-young-working-elderly
population-young-working-elderly-with-projections
population-young-working-old
postnatal-care
potash-fertilizer-application-per-hectare-of-cropland
potato-production
potato-yields
poultry-livestock-count
poultry-production-tonnes
poultry-yields-meat-per-animal
power-outages-in-firms-per-month
precentage-enrolled-in-private-institutions-at-the-primary-education-level
press-freedom-fh
press-freedom-index-rsf
prevalence-by-mental-and-substance-use-disorder
prevalence-cysticercosis
prevalence-of-anemia-in-children
prevalence-of-anemia-in-pregnant-women
prevalence-of-anemia-in-women-of-reproductive-age-aged-15-29
prevalence-of-anemia-in-women-of-reproductive-age-vs-gdp-per-capita
prevalence-of-diarrheal-disease-vs-ors
prevalence-of-drug-use-disorders-by-age
prevalence-of-drug-use-disorders-males-vs-females
prevalence-of-hepatitis-b-surface-antigen
prevalence-of-lymphatic-filariasis
prevalence-of-mental-and-substance-disorders-by-age
prevalence-of-modern-contraception-methods-vs-womens-mean-years-of-schooling
prevalence-of-night-blindness-in-pregnant-women
prevalence-of-night-blindness-in-pre-school-children
prevalence-of-onchocerciasis
prevalence-of-polio-rates-in-the-united-states
prevalence-of-stunting-male-vs-female
prevalence-of-stunting-vs-improved-sanitation-facilities
prevalence-of-tuberculosis-by-drug-susceptibility
prevalence-of-undernourishment
prevalence-of-undernourishment-in-developing-countries-since-1970
prevalence-of-undernourishment-vs-daily-supply-of-calories
prevalence-of-undernourishment-vs-share-of-children-who-are-stunted
prevalence-of-vitamin-a-deficiency-in-children
prevalence-of-vitamin-a-deficiency-in-pregnant-women
prevalence-rate-of-cardiovascular-disease
price-changes-consumer-goods-services-united-states
price-five-simon-ehrlich-materials
price-per-kg-of-gold
primary-completion-rate-adjusted-gender-parity-index
primary-edu-spending-vs-overall-edu-spending
primary-energy-cons
primary-energy-consumption-by-region
primary-energy-consumption-by-source
primary-energy-consumption-from-solar
primary-energy-consumption-from-solar-and-wind
primary-energy-fossil-nuclear-renewables
primary-energy-hydro
primary-energy-mix-uk
primary-energy-nuclear
primary-energy-renewables
primary-energy-share-nuclear-renewables
primary-energy-source-bar
primary-energy-wind
primary-enrollment-selected-countries
primary-school-attendance-selected-countries
primary-schools-with-access-to-internet
primary-secondary-enrollment-completion-rates
primary-sub-energy-source
prison-population-rate
private-civil-liberties-index
private-health-expenditure-per-person
private-investment-in-artificial-intelligence
private-investment-in-artificial-intelligence-by-focus-area
private-investment-in-artificial-intelligence-cset
probability-of-dying-by-age
probability-of-dying-that-year-among-females-of-a-given-age
probability-of-dying-that-year-among-males-of-a-given-age
probability-that-a-male-will-outlive-a-female
probability-that-a-newborn-will-die-in-the-first-year-of-life-by-sex
prod-cons-co2-per-capita
production-consumption-carbon-intensity-energy
production-consumption-energy-per-person
production-printed-books-half-century
production-vs-consumption-co2-emissions
production-vs-consumption-energy
productivity-of-small-scale-food-producers
productivity-vs-annual-hours-worked
progress-toward-productive-and-sustainable-agriculture
progress-towards-guinea-worm-disease-eradication
progress-towards-polio-eradication
prohibition-of-nuclear-weapons
projected-change-dependency-ratios
projected-cropland-by-2050
projected-habitat-loss-extent-bau
projected-population-under-age-5
projections-for-global-peak-agricultural-land
projections-of-the-number-of-children-per-woman-by-education-scenario
projections-of-the-rate-of-no-education-based-on-current-global-education-trends-1970-2050
proportion-countries-migration-policies-criteria
proportion-of-animal-breeds-genetic-conservation
proportion-of-children-developmentally-on-track
proportion-of-forest-area-certified-under-an-independently-verified-certification-scheme
proportion-of-forest-area-within-legally-established-protected-areas
proportion-of-forest-area-with-long-term-management-plan
proportion-of-important-sites-for-freshwater-biodiversity-covered-by-protected-areas
proportion-of-labor-force-who-are-women
proportion-of-local-breeds-at-risk-of-extinction
proportion-of-members-of-developing-countries-in-international-organizations
proportion-of-population-served-by-municipal-waste-collection
proportion-of-unemployed-using-specific-search-methods
proportion-of-women-in-senior-and-middle-management-positions
proportion-of-women-subjected-to-physical-or-sexual-violence
proportion-of-women-who-make-their-own-informed-health-care-decisions
proportion-tariff-lines-applied-to-imports-from-ldcs
proportion-using-safely-managed-drinking-water
proportion-with-basic-handwashing-facilities-urban-vs-rural
proportion-with-ict-skills-by-sex
proportion-with-ict-skills-in-presentations
prostate-cancer-death-rate-in-men
protected-area-coverage-of-marine-key-biodiversity-areas
protected-terrestrial-biodiversity-sites
protection-of-the-rights-of-small-scale-fisheries
protein-efficiency-of-meat-and-dairy-production
protein-energy-malnutrition-mortality-rates-in-children
protein-folding-prediction-accuracy
psychiatrists-working-in-the-mental-health-sector
public-healthcare-spending-share-gdp
public-health-expenditure-share-gdp
public-health-insurance-coverage
public-morality-laws-on-non-traditional-sexual-relations
public-opposition-to-nuclear-energy-production
public-sector-corruption-index
public-sector-employment-as-a-share-of-total-employment
public-trust-in-government
pupil-teacher-ratio-for-primary-education-by-country
pupil-teacher-ratio-in-pre-primary-education
quality-vs-quantity-of-schooling
quantity-oil-spills
quantity-oil-spills-decadal-average
quantum-bits-per-processor
railways-passengers-carried-passenger-km
rapeseed-yields
rate-of-acute-flaccid-paralysis-from-non-polio-causes
rate-of-armed-conflicts
rate-of-child-deaths-attributed-to-child-and-maternal-malnutrition
rate-of-disease-burden-from-drug-use-disorders-who
rate-of-interstate-conflicts
rate-of-new-cases-of-cancer-by-type
rate-of-new-cervical-cancer-cases
rate-of-new-cervical-cancer-cases-gco
rate-of-state-based-conflicts
rate-of-twin-deliveries
rate-of-violent-deaths-non-state-societies
rate-of-violent-deaths-state-societies
rate-of-violent-victimizations-at-school-us
ratification-and-accession-to-unclos
ratio-of-business-trips-to-trips-for-personal-reasons
ratio-of-female-to-male-labor-force-participation-rates-ilo-wdi
ratio-of-female-to-male-labor-force-participation-rates-slopes
ratio-of-inbound-to-outbound-tourists
ratio-of-same-day-to-tourist-trips
ratio-of-the-literacy-rate-between-young-women-and-men
real-commodity-price-index-metals
real-transport-and-communication-costs
received-official-development-assistance-grants-for-poverty-reduction
recycling-rates-glass
recycling-rates-paper-and-cardboard
red-list-index
reduction-global-antibiotic-use
reduction-in-hdi-when-adjusting-for-inequalities
reduction-in-income-inequality
refugee-population-by-country-or-territory-of-asylum
refugee-population-by-country-or-territory-of-origin
regional-averages-of-the-composite-gender-equality-index
region-share-tropical-deforestation
regulation-financial-markets
regulation-illegal-fishing
regulations-antibiotics-growth-promotion
relative-change-in-female-height
relative-change-male-height
relative-share-of-passenger-kilometers-travelled-by-rail-and-road
relative-weight-of-two-forms-of-consumption-taxation
remaining-life-expectancy-at-different-ages
remaining-life-expectancy-at-different-ages-females
remaining-life-expectancy-at-different-ages-males
remittance-costs-as-share-of-amount-remitted
renewable-electricity-generating-capacity-per-capita
renewable-electricity-per-capita
renewable-energy-consumption
renewable-energy-gen
renewable-energy-investment-of-gdp
renewable-nuclear-direct-substitution
renewable-share-energy
renewable-water-resources-per-capita
replacement-fertility-rate
reported-cases-of-acute-african-trypanosomiasis
reported-cases-of-human-african-trypanosomiasis-t-b-gambiense
reported-cases-of-leprosy
reported-cases-of-measles
reported-number-of-smallpox-infections-by-world-region
reported-paralytic-polio-cases-and-deaths-in-the-united-states-since-1910
reported-paralytic-polio-cases-per-1-million-people
reported-rabies-deaths
reported-rate-of-new-cervical-cancer-cases
reported-share-of-people-experiencing-homelessness
reported-vs-estimated-total-number-of-paralytic-polio-cases-globally
reporting-of-mental-health-system-data-in-the-past-two-years
representation-of-women-in-lower-chamber-of-parliament
representation-of-women-in-the-judiciary
representation-of-women-in-the-upper-chamber-of-parliament
researchers-in-rd-per-million-people
researchers-in-rd-per-million-people-vs-gdp-pc
research-spending-gdp
resources-statistical-capacity
respect-for-counterarguments-score
respiratory-disease-death-rate
respiratory-disease-death-rate-gbd
respiratory-disease-deaths-by-age
respiratory-infection-death-rate-who-mdb
respiratory-infections-death-rate-age-group
respiratory-pathogens-share-detected-seattle-flu-study
revenue-from-corporate-income-taxes-gdp
revenues-for-public-schools-by-source-gdp-us
rice-production
rice-production-by-region
rice-yields
right-to-change-legal-gender-equaldex
rigorous-and-impartial-public-administration-score
risk-of-impoverishing-expenditure-for-surgical-care
road-accident-deaths-per-passenger-kilometers
road-death-rate-vs-gdp-per-capita
road-deaths-by-type
road-deaths-in-great-britain-by-road-user
road-deaths-over-the-long-term
road-incident-deaths-by-age
road-miles-nox-emissions
road-mortality-rate-comparison
rock-to-metal-ratio
rotavirus-number-unvaccinated
rotavirus-vaccine-immunization-schedule
routes-to-diagnosis
rubella-cases-in-the-united-states
rubella-number-unvaccinated
rubella-vaccination-coverage
rubella-vaccine-immunization-schedule
rule-of-law-index
rule-of-law-index-bti
rural-land-below-5-meters
rural-population-with-improved-water
rural-without-improved-sanitation
rural-without-improved-water
rye-yield
safe-sanitation-without
safety-walking-alone
sales-antibiotics-livestock-europe
sales-of-cigarettes-per-adult-per-day
same-sex-marriage-country-count
same-sex-sexual-acts-equaldex
same-sex-sexual-acts-legal
same-sex-sexual-acts-punished-by-death
sanitation-facilities-coverage
sanitation-facilities-coverage-in-rural-areas
sanitation-facilities-coverage-in-urban-areas
scarcity-water-per-kg-poore
scarcity-water-protein-poore
scarcity-water-use-kcals
scheduled-teaching-time-that-teachers-are-in-the-classroom
schistosomiasis-treatment-coverage
schizophrenia-prevalence
schizophrenia-prevalence-by-age
schizophrenia-prevalence-males-vs-females
scholarly-publications-on-artificial-intelligence-per-million-people
school-life-expectancy-primary-gender-parity-index-gpi
schools-access-computers
schools-access-drinking-water
schools-access-to-electricity
schools-materials-students-with-disabilities
science-helps-a-lot-treating-anxiety-depression-vs-gdp-per-capita
scientific-and-technical-journal-articles
scientific-publications-per-million
seafood-and-fish-production-thousand-tonnes
sea-ice-anomaly-in-the-antarctic-by-month
sea-ice-anomaly-in-the-arctic-by-month
sea-level
seasonal-temp-anomaly-us
sea-surface-temperature
sea-surface-temperature-anomaly
seawater-ph
secondary-net-enrollment-gpi
seized-rhino-horns
self-harm-death-rates-by-age
self-reported-freedom
self-reported-hopefulness
self-reported-life-satisfaction-young-vs-old-people
self-reported-trust-attitudes
separation-of-powers-score-bti
service-exports-and-imports-gdp
sesame-seed-production
severe-bleaching-events-enso
severe-food-insecurity-undernourishment
sex-ratio-at-birth
sex-ratio-at-birth-by-birth-order
sex-ratio-at-birth-vs-five-years-old
sex-ratio-at-five-years-old
sex-ratio-at-sixty-years-old
sex-ratio-by-age
share-adults-bank-account-financial-institution-mobile-money
share-agreeing-most-people-can-be-trusted-vs-gdp-per-capita
share-agreeing-most-people-can-be-trusted-vs-most-people-would-try-to-take-advantage-of-you
share-agrees-vaccines-are-important-wellcome
share-agree-vaccines-are-safe-wellcome
share-agriculture-smallholder-farms
share-artificial-intelligence-job-postings
share-believe-climate
share-cancers-diagnosed-via-screening-in-england-by-stage-of-cancer
share-car-sales-battery-plugin
share-car-stocks-electric
share-cereal-human-food
share-cereals-animal-feed
share-cereals-industrial-uses
share-co2-embedded-in-trade
share-co2-emissions-deforestation
share-co2-emissions-vs-population
share-co2-vs-population
share-companies-using-artificial-intelligence
share-countries-accredited-independent-national-human-rights-institutions
share-covered-by-one-social-protection-benefit
share-cumulative-co2-oil
share-deaths-air-pollution
share-deaths-cardiovascular-disease
share-deaths-from-natural-disasters
share-deaths-indoor-pollution
share-deaths-outdoor-pollution
share-deaths-secondhand-smoke
share-deaths-suicide
share-deaths-unsafe-sanitation
share-deaths-unsafe-water
share-deforestation-agricultural-products
share-deforestation-domestic-consumption
share-deforestation-exported
share-degraded-land
share-disagrees-vaccines-are-effective
share-disagrees-vaccines-are-important
share-disagree-vaccines-are-safe-wellcome-trust
share-edu-spending-gdp-vs-share-edu-total-spending
share-elec-by-source
share-electricity-coal
share-electricity-fossil-fuels
share-electricity-gas
share-electricity-hydro
share-electricity-low-carbon
share-electricity-nuclear
share-electricity-oil
share-electricity-renewables
share-electricity-solar
share-electricity-source-facet
share-electricity-source-wb
share-electricity-wind
share-energy-source-sub
share-enrolled-in-private-institutions-at-the-pre-primary-education-level
share-farms-smallholders
share-farms-smallholders-vs-gdp
share-firms-top-female-manager
share-food-exports
share-food-lost-type
share-food-miles-by-method
share-global-co2-cement
share-global-co2-coal
share-global-co2-flaring
share-global-co2-gas
share-global-co2-including-land
share-global-co2-oil
share-global-cumulative-co2-cement
share-global-cumulative-co2-coal
share-global-cumulative-co2-flaring
share-global-cumulative-co2-gas
share-global-deforestation
share-global-excess-nitrogen
share-global-excess-phosphorous
share-global-food-emissions
share-global-forest
share-global-forest-expansion
share-global-ghg-emissions
share-global-methane-emissions
share-graduates-stem-female
share-manufacture-exports
share-nitrous-oxide-emissions
share-of-adults-borrowing-from-a-financial-institution-vs-family-or-friends
share-of-adults-borrowing-from-different-sources
share-of-adults-who-perceive-their-rights-to-land-as-secure
share-of-adults-who-report-saving-money-in-the-past-year
share-of-adults-who-smoke
share-of-agricultural-land-being-productively-and-sustainably-used
share-of-agricultural-land-owners-that-are-women
share-of-all-cancer-deaths-attributable-to-alcohol-use
share-of-all-cancer-deaths-by-risk-factor
share-of-arable-land-which-is-organic
share-of-births-by-age-of-mother
share-of-births-outside-marriage
share-of-businesses-asked-for-bribes-by-type-of-transaction-with-public-officials
share-of-calories-from-animal-protein-vs-mean-male-height
share-of-cancer-deaths-attributed-to-alcohol-use-by-type
share-of-cancer-deaths-attributed-to-all-risk-factors
share-of-cancer-deaths-attributed-to-different-risk-factors
share-of-cancer-deaths-attributed-to-risk-factors
share-of-cancer-deaths-by-cancer-type
share-of-cancer-deaths-linked-to-dietary-risk-factors-by-cancer-type
share-of-cancer-deaths-linked-to-high-bmi-by-type
share-of-cancer-deaths-linked-to-tobacco-use-by-cancer-type
share-of-cancers-attributed-to-9-hpv-types
share-of-central-government-expenditures-funded-by-taxes
share-of-cervical-and-all-cancer-deaths-due-to-unsafe-sex
share-of-children-achieving-minimum-proficiency-in-reading-and-math-by-education-level
share-of-children-achieving-minimum-reading-proficiency-by-the-end-of-primary-education
share-of-children-ages-13-15-who-report-being-bullied
share-of-children-ages-13-15-who-report-being-in-a-school-fight-last-year
share-of-children-immunized-dtp3
share-of-children-living-with-a-single-parent
share-of-children-reaching-sufficient-reading-comprehension-by-the-end-of-lower-secondary-age
share-of-children-under-fifteen-years-old-with-hiv
share-of-children-underweight
share-of-children-vaccinated-against-measles
share-of-children-vaccinated-against-measles-vs-share-vaccinated-against-dpt3
share-of-children-vaccinated-with-mcv2
share-of-children-who-are-stunted-in-urban-and-rural-areas
share-of-children-who-are-stunted-vs-co-emissions-per-capita
share-of-children-who-experienced-violence
share-of-children-with-a-weight-too-low-for-their-height-wasting
share-of-children-younger-than-5-who-suffer-from-stunting
share-of-clinical-trials-that-report-results-in-time-by-country
share-of-clinical-trials-that-report-results-within-a-year-over-time
share-of-countries-by-gender-of-the-chief-executive
share-of-countries-by-gender-of-the-head-of-government
share-of-countries-by-gender-of-the-head-of-state
share-of-countries-region-reporting-confirmed-infections-glass
share-of-countries-testing-confirmed-bacterial-infections-for-antibiotic-susceptibility
share-of-countries-that-have-had-a-woman-as-leader
share-of-countries-with-procedures-for-community-participation-in-water-sanitation-management
share-of-cumulative-co2
share-of-day-women-spend-on-unpaid-domestic-and-care-work
share-of-deaths-by-cause
share-of-deaths-by-risk-factor
share-of-deaths-cause-is-registered
share-of-deaths-from-cardiovascular-diseases-men-women
share-of-deaths-from-homicide
share-of-deaths-from-major-causes
share-of-deaths-from-opioid-overdoses
share-of-deaths-from-terrorism
share-of-deaths-from-underlying-causes
share-of-deaths-registered
share-of-deliveries-by-singleton-twin-or-multiple-status
share-of-dietary-energy-derived-from-protein-vs-gdp-per-capita
share-of-dietary-energy-supply-from-carbohydrates-vs-gdp-per-capita
share-of-dietary-energy-supply-from-fats-vs-gdp-per-capita
share-of-disease-burden-from-communicable-diseases-vs-gdp
share-of-disease-burden-from-ncds-vs-gdp
share-of-e-coli-bloodstream-infections-due-to-antimicrobial-resistant-bacteria
share-of-education-in-government-expenditure
share-of-eggs-produced-by-different-housing-systems
share-of-electricity-production-from-renewable-sources
share-of-electricity-production-from-solar-and-wind
share-of-employed-women-working-in-agriculture-vs-gdp-per-capita
share-of-employee-compensation-in-public-spending
share-of-energy-from-cereals-roots-and-tubers-vs-gdp-per-capita
share-of-female-workers-by-sector
share-of-final-energy-consumption-from-renewable-sources
share-of-firms-for-which-access-to-finance-is-a-major-constraint
share-of-firms-that-say-corruption-is-a-big-problem-for-them
share-of-fish-stocks-overexploited
share-of-fish-stocks-that-are-sustainably-fished
share-of-foreign-aid-spent-within-donor-countries
share-of-global-consumption-based-co-emissions-and-population
share-of-global-habitable-land-needed-for-agriculture-if-everyone-had-the-diet-of
share-of-global-merchandise-exports
share-of-global-mismanaged-plastic-waste
share-of-global-services-exports
share-of-government-expenditure-going-to-interest-payments
share-of-gov-expenditure-in-gdp-vs-gdp-per-capita
share-of-health-facilities-with-essential-medicines
share-of-households-by-type
share-of-households-consuming-iodized-salt
share-of-individuals-using-the-internet
share-of-individuals-who-own-a-mobile-telephone-by-sex
share-of-industrial-wastewater-which-is-treated
share-of-invasive-cervical-cancers-caused-by-each-hpv-type
share-of-land-area-used-for-agriculture
share-of-land-area-used-for-arable-agriculture
share-of-land-covered-by-lakes-and-rivers
share-of-low-birthweight-babies-born
share-of-low-carbon-energy-vs-gdp
share-of-low-pay-earners-who-are-female-vs-gdp-per-capita
share-of-lung-cancer-deaths-attributed-to-air-pollution
share-of-male-vs-female-employment-in-agri
share-of-male-vs-female-employment-in-industry
share-of-male-vs-female-employment-in-services
share-of-married-women-ages-15-49-years-whose-need-for-family-planning-is-satisfied
share-of-men-in-england-and-wales-who-have-ever-married-by-age
share-of-mothers-in-low--and-middle-income-countries-who-lost-a-child-under-5
share-of-mothers-receiving-at-least-four-antenatal-visits-during-pregnancy
share-of-mothers-receiving-at-least-one-antenatal-visit-during-pregnancy
share-of-mothers-who-have-lost-a-child-under-5
share-of-mothers-who-have-lost-an-infant
share-of-mountain-land-that-is-degraded
share-of-new-cancers-caused-by-all-known-infections-by-type
share-of-new-cancers-caused-by-all-known-infectious-agents
share-of-new-cancers-caused-by-helicobacter-pylori-bacteria
share-of-one-year-olds-who-received-the-final-dose-of-pneumococcal-vaccine
share-of-one-year-olds-who-received-the-rotavirus-vaccine
share-of-out-of-pocket-expenditure-on-healthcare
share-of-out-of-pocket-expenditure-vs-gdp-per-capita
share-of-people-paying-bribes-vs-corruption-perception
share-of-people-saying-they-do-not-want-homosexual-neighbors
share-of-people-who-find-political-decision-making-inclusive-and-responsive
share-of-people-who-recently-paid-a-bribe-or-were-asked-for-one-vs-political-corruption-index
share-of-people-who-say-accepting-a-bribe-is-never-justifiable
share-of-people-who-say-they-are-happy
share-of-people-who-say-they-are-happy-eurobarometer
share-of-people-who-think-homosexuality-is-never-justified
share-of-people-who-think-political-parties-are-corrupt
share-of-people-who-think-their-life-will-improve-in-the-next-years
share-of-people-with-disputes-using-a-dispute-resolution-mechanism
share-of-people-worried-about-terrorism
share-of-population-15-years-and-older-with-no-education
share-of-population-covered-by-social-protection
share-of-population-in-extreme-poverty
share-of-population-in-multidimensional-poverty-urban-vs-rural-cme-scatter
share-of-population-living-in-cities-towns-and-villages
share-of-population-satisfied-with-government-services
share-of-populations-increasing-stable-or-decreasing-in-the-living-planet-index
share-of-population-urban
share-of-population-using-safely-managed-drinking-water-services-rural-vs-urban
share-of-population-with-cancer-age-standardized
share-of-population-with-cancer-by-age
share-of-population-with-cancer-crude
share-of-population-with-cancer-types
share-of-population-with-cancer-vs-median-age
share-of-population-with-improved-sanitation-faciltities
share-of-population-with-large-household-expenditures-on-health-10pc
share-of-population-with-moderate-or-severe-food-insecurity
share-of-population-with-severe-food-insecurity
share-of-potential-polio-cases-with-adequate-stool-collection
share-of-primary-energy-consumption-by-source
share-of-primary-energy-from-solar-and-wind
share-of-primary-school-teachers-who-are-female
share-of-public-expenditure-on-healthcare-by-country
share-of-rural-population-near-a-road
share-of-rural-population-with-electricity-access-vs-share-of-total-population-with-electricity-access
share-of-rural-population-with-improved-sanitation-faciltities
share-of-s-aureus-bloodstream-infections-that-are-resistant-to-antibiotics
share-of-schools-with-access-to-single-sex-basic-sanitation
share-of-secondary-school-teachers-who-are-female
share-of-services-in-total-exports
share-of-single-parent-households
share-of-small-with-illicit-origin
share-of-species-evaluated-iucn
share-of-stage-1-cancers-by-diagnosis-route-in-england
share-of-stage-4-cancers-by-diagnosis-route-in-england
share-of-students-achieving-minimum-proficiency-in-reading-and-math-by-education-level
share-of-students-at-end-of-lower-secondary-education-achieving-minimum-math-proficiency
share-of-students-at-end-of-lower-secondary-education-with-minimum-reading-proficiency
share-of-students-at-end-of-primary-education-achieving-minimum-math-proficiency
share-of-students-at-end-of-primary-education-achieving-minimum-reading-proficiency
share-of-students-from-abroad
share-of-students-in-early-primary-education-achieving-minimum-math-proficiency
share-of-students-in-early-primary-education-achieving-minimum-reading-proficiency
share-of-students-in-top-pisa-mathematics-score-level-male-vs-female
share-of-students-studying-abroad
share-of-teachers-in-primary-education-who-are-trained
share-of-teachers-in-secondary-education-who-are-trained
share-of-teachers-in-tertiary-education-who-are-female
share-of-the-daily-calorie-supply-that-comes-from-animal-protein
share-of-the-population-at-risk-of-catastrophic-expenditure-when-surgical-care-is-required
share-of-the-population-infected-with-hiv
share-of-the-population-reporting-having-felt-discriminated-against
share-of-the-population-using-improved-sanitation-facilities
share-of-the-population-victim-to-physical-and-sexual-harassment
share-of-the-population-with-access-to-electricity
share-of-the-population-with-access-to-sanitation-facilities
share-of-the-population-with-a-completed-post-secondary-education
share-of-the-population-with-at-least-some-secondary-education
share-of-the-population-with-basic-numeracy-skills-by-birth-decade
share-of-the-population-with-completed-tertiary-education
share-of-the-population-with-latent-tuberculosis-infection
share-of-the-population-without-access-to-clean-fuels-for-cooking
share-of-the-rural-and-urban-population-with-access-to-clean-fuels-for-cooking
share-of-the-total-land-area-burnt-by-wildfires-each-year
share-of-the-urban-and-rural-population-using-safely-managed-drinking-water-services
share-of-the-urban-and-rural-population-using-safely-managed-sanitation-services
share-of-the-workforce-employed-in-the-coal-industry-united-kingdom
share-of-the-world-population-with-at-least-basic-education
share-of-total-disease-burden-by-cause
share-of-total-energy-used-in-agriculture-and-forestry
share-of-urban-population-by-size-of-the-agglomeration
share-of-urban-population-by-source
share-of-urban-population-living-in-inadequate-housing
share-of-urban-population-living-in-slums
share-of-urban-population-with-convenient-access-to-open-public-spaces
share-of-urban-population-with-improved-sanitation-facilities
share-of-victims-who-reported-crime-to-the-police
share-of-violent-deaths-non-state-societies
share-of-violent-deaths-prehistoric-archaeological-sites
share-of-violent-deaths-state-societies
share-of-women-aged-1549-who-are-married-or-in-a-union
share-of-women-having-births
share-of-women-homeless-flow-count
share-of-women-homeless-point-in-time-count
share-of-women-in-england-and-wales-who-have-ever-married-by-age
share-of-women-in-local-government
share-of-women-in-ministerial-positions
share-of-women-in-parliament
share-of-women-in-parliament-ipu
share-of-women-in-top-income-groups-atkinson-casarico-voitchovsky-2018
share-of-women-married-or-in-a-union
share-of-women-using-modern-contraceptive-methods
share-of-women-who-experienced-violence-by-an-intimate-partner-un
share-of-women-who-have-had-no-births-across-their-childbearing-years
share-of-working-children-who-work-only
share-of-world-merchandise-trade-by-type-of-trade
share-of-world-merchandise-trade-by-type-of-trade-percent
share-of-young-women-vs-men-who-are-not-in-education-employment-or-training
share-or-agricultural-population-with-land-ownership-rights-by-sex
share-people-trust-journalists-country
share-people-trust-neighborhood
share-people-trust-science
share-plastic-fate
share-plastic-waste-recycled
share-population-female
share-population-mobile-phone
share-primary-school-age-out-of-school
share-primary-school-age-out-of-school-vs-gdp-per-capita
share-regions-with-land-use
share-social-protection-in-government-exp-oecd
share-species-traded
share-threatened-species
share-undernourished-vs-gdp-pc
share-urban-and-rural-population
share-using-safely-managed-sanitation
share-voting-rights-international-organizations
share-who-agree-vaccines-are-effective
share-who-agree-with-the-statement-when-jobs-are-scarce-men-should-have-more-right-to-a-job-than-women
share-who-are-worried-about-vs-share-of-deaths-from-terrorism
share-who-report-lifetime-anxiety-or-depression
share-who-say-its-extremely-important-for-the-national-government-to-fund-research-on-anxietydepression
share-who-trust-government
share-with-4g-mobile-network-coverage
share-with-access-to-electricity-vs-per-capita-energy-consumption
share-with-convenient-access-to-an-open-public-space
share-with-convenient-access-to-public-transport
share-with-drug-use-disorders
share-with-mental-and-substance-disorders
share-with-mental-health-males-vs-females
share-with-mental-health-or-development-disorder
share-without-improved-sanitation
share-without-improved-water
significant-earthquakes
significant-volcanic-eruptions
smalsmall-scale-industries-loan
snow-cover-north-america
social-expenditure-as-percentage-of-gdp
social-spending-oecd-longrun
so-emissions-by-world-region-in-million-tonnes
soil-lifespans
solar-and-wind-power-generation
solar-electricity-per-capita
solar-energy-consumption
solar-energy-consumption-by-region
solar-pv-cumulative-capacity
solar-pv-energy-consumption-vs-solar-pv-capacity
solar-pv-prices
solar-pv-prices-vs-cumulative-capacity
solar-pv-system-costs
solar-share-energy
sons-and-daughters-inheritance
sorghum-yield
sources-of-air-pollution-in-the-uk
southern-white-rhinos
sovereign-state-butcher-griffiths
sovereign-state-cow
sovereign-state-gleditsch-ward
soybean-production
soybean-production-and-use
soybean-yields
soy-production-yield-area
space-objects-by-orbit
species-represented-in-the-living-planet-index
spring-temperature-anomalies
stability-democratic-institutions-index-bti
staff-compensation-as-share-of-total-expenditure-in-public-education-all-levels
stand-alone-policy-or-plan-for-mental-health
state-capacity-index
stateness-index-bti
states-involved-in-interstate-conflicts
states-involved-in-state-based-conflicts
states-involved-in-wars
statin-use-cardiovascular-disease-death-rate
statin-use-vs-share-of-population-with-high-blood-pressure
statistical-performance-indicator
status-of-buruli-ulcer-endemicity
status-of-endemicity-of-cutaneous-leishmaniasis
status-of-endemicity-of-onchocerciasis
status-of-endemicity-of-visceral-leishmaniasis
status-of-trachoma-as-a-public-health-problem
status-of-yaws-endemicity
statutory-corporate-income-tax-rate
stillbirth-rate
stomach-cancer-death-rate
stratospheric-chorine-concentrations
stratospheric-ozone-concentration
stratospheric-ozone-concentration-projections
stroke-death-rates
stroke-death-rates-by-age
stroke-deaths-by-age
strong-civil-society-index
strong-elected-local-governments-index
strong-elected-regional-governments-index
students-in-grade-2-who-cant-read-a-single-word-ca-2015
stunting-ihme-vs-gdp
stunting-vs-level-of-prosperity-over-time
sub-energy-fossil-renewables-nuclear
suffrage
sugar-beet-production
sugar-beet-yields
sugar-cane-production
sugar-cane-yields
suicide-and-other-terrorist-attacks
suicide-death-rates
suicide-death-rates-by-sex-who
suicide-deaths-by-age
suicide-rate-1990-2019
suicide-rate-2000-2019-who
suicide-rate-for-15--to-49-year-olds
suicide-rate-male-female-who-mdb
suicide-rates-among-young-men-who-mdb
suicide-rates-among-young-people-who-mdb
suicide-rates-among-young-women-who-mdb
suicide-rates-by-age-detailed
suicide-rates-by-age-detailed-who
suicide-rates-by-age-who-mdb
suicide-rates-source-comparison
suicide-rates-source-comparison-crude
suicide-rate-vs-income-inequality
suicide-rate-who-mdb
suicide-vs-violent-deaths
sulphur-dioxide-and-coal
sumatran-rhinos
summer-temperature-anomalies
sunflower-seed-yield
supercomputer-power-flops
support-policies-climate
support-political-climate-action
support-public-action-climate
surgeons-per-100000
survey-animal-pain-sentience
survey-dietary-choices-sentience
survival-ages-across-the-population
survival-to-age-65-of-cohort
sustainable-fisheries-as-a-proportion-of-gdp
sweden-life-expectancy-smallpox-deaths
sweden-official-covid-deaths
systems-track-gender-equality
tariff-rate-applied-weighted-mean-all-products
tariff-rates
taxes-on-goods-and-services-gdp
taxes-on-incomes-of-individuals-and-corporations-gdp
taxes-on-income-vs-taxes-on-goods-and-services
tax-revenue-national-income-longrun
tax-revenue-per-capita-and-public-health-spending-per-capita-in-developing-countries-in
tax-revenues-as-a-share-of-gdp-unsdg
tax-revenues-as-a-share-of-gdp-unu-wider
tax-revenues-by-source-gdp-la
tax-revenue-share-gdp-oecd-grsd
tax-revenues-vs-electoral-democracy-index
tax-revenues-vs-gdp-per-capita
tax-revenues-vs-income-inequality
tea-production-by-region
technology-adoption-by-households-in-the-united-states
technology-infrastructure-diffusion-uk
technology-infrastructure-diffusion-us
temp-deaths-zhao
temperature-anomaly
temperature-anomaly-vs-latitude
terrain-ruggedness-index
terrestrial-protected-areas
terrorism-attacks-by-severity
terrorism-deaths
terrorism-deaths-by-region
terrorism-deaths-rate
terrorist-attacks
terrorist-attacks-by-method
terrorist-attacks-by-method-stacked
terrorist-attacks-by-region
terrorist-attacks-by-target
terrorist-attacks-fatalities-and-injuries
testing-coverage-of-confirmed-bacterial-infections
test-scores-ai-capabilities-relative-human-performance
tetanus-cases-vs-tetanus-vaccination-coverage
tetanus-death-rate
tetanus-deaths-by-age-group
tetanus-deaths-by-region
tetanus-mortality-in-children-under-5
tfp-at-constant-national-prices-20111
the-burden-of-disease-vs-gdp-per-capita
the-decade-of-the-last-recorded-case-of-paralytic-polio-by-country
the-discrepancy-between-the-reported-and-actual-number-of-global-smallpox-cases
the-gender-wage-ratio-in-different-income-percentiles
the-long-term-energy-transition-in-europe
the-number-of-cases-of-infectious-diseases
the-number-of-new-tetanus-infections-by-world-region
the-number-of-reported-paralytic-polio-cases
the-number-of-reported-paralytic-polio-cases-by-world-region
the-percentage-of-neonates-protected-at-birth-against-neonatal-tetanus
the-price-for-lighting-per-million-lumen-hours-in-the-uk-in-british-pound
thermal-efficiency-factor
the-shrinking-gender-gap-in-high-level-jobs-and-collective-barganing-coverage
the-worlds-number-of-vaccinated-one-year-olds
third-gender-legally-recognized
third-gender-recognition-equaldex
threatened-bird-species
threatened-endemic-bird-species
threatened-endemic-coral
threatened-endemic-mammal-species
threatened-mammal-species
ti-corruption-perception-index
time-required-to-start-business
time-spend-in-domestic-work-female-vs-male
time-spent-alone-by-age-and-gender
time-spent-on-unpaid-care-and-domestic-work
time-spent-with-relationships-by-age-us
time-women-and-men-spend-on-leisure
tobacco-production
tomato-production
tomato-yields
top-income-tax-rates-piketty
total-affected-by-natural-disasters
total-agricultural-area-over-the-long-term
total-agricultural-land-use-per-person
total-applied-phosphorous-crops
total-cancer-deaths-by-type
total-cardiologists-per-million-people
total-deaths-comparison
total-disease-burden
total-disease-burden-by-cause
total-disease-burden-who
total-fertility-rate-vs-cohort-fertility-rate-vs-tempo-adjusted-tfr
total-financial-assistance-and-flows-for-agriculture-by-recipient
total-ghg-emissions
total-ghg-emissions-excluding-lufc
total-government-expenditure-on-education-gdp
total-gov-expenditure-gdp-wdi
total-gov-expenditure-percapita-oecd
total-healthcare-expenditure-gdp
total-inward-financial-flows-from-drug-trafficking
total-live-births-hfd
total-manufacturing-value-added-from-high-tech
total-net-enrollment-rate-in-primary-education
total-nitrogen-inputs-crops
total-number-of-births-by-birth-order
total-number-of-deaths-by-cause
total-number-of-people-aged-15-with-no-education-in-millions-by-continent-1970-2050
total-number-of-rcts-published-in-high-ranked-medical-journals
total-oda-for-aid-for-trade-by-donor
total-oda-for-aid-for-trade-by-recipient
total-oda-for-biodiversity-by-donor
total-oda-for-biodiversity-by-recipient
total-oda-for-infrastructure-by-recipient
total-oda-for-water-supply-and-sanitation-by-recipient
total-official-development-assistance-for-technical-cooperation
total-outward-financial-flows-from-drug-trafficking
total-reserves-in-months-of-imports
total-taxation-of-gdp
total-waste-generation
tourism-gdp-proportion-of-total-gdp
tourist-departures-per-1000-vs-gdp
trachoma-prevalence-age-standardized-ihme
trade-as-share-of-gdp
traded-energy-share-domestic
trade-openness-in-europe
training-computation-vs-dataset-size-in-notable-ai-systems-by-researcher-affiliation
transgender-military
transistors-per-microprocessor
transparent-laws-row
trawling-footprint-region
treatment-of-hazardous-waste
tree-cover-loss
tree-cover-loss-by-dominant-driver
tree-cover-loss-from-wildfires
trips-by-domestic-tourists-per-person
trust-healthcare-vs-vaccine-safety
trust-in-others-vs-trust-in-police
trust-organizations-wvs
trust-people-by-group-wvs
trust-state-institutions-wvs
tsunami-deaths
tuberculosis-case-detection-rate
tuberculosis-cases-attributable-to-risk-factors
tuberculosis-death-rate
tuberculosis-deaths-who
tuberculosis-funding-versus-budget-requirement
tuberculosis-incidence-uncertainty-intervals
tuberculosis-treatment-success-rate-by-type
twentieth-century-of-deaths-us
uk-covid-hospital-patients
uk-covid-positivity
uk-cumulative-covid-deaths-rate
uk-daily-covid-admissions
uk-daily-covid-cases-7day-average
uk-daily-covid-deaths
uk-daily-new-covid-cases
uk-number-vehicles-miles-road-deaths
unadjusted-gender-wage-gap-including-unemployed
under-5-mortality-rate-sdgs
unemployment-rate-men-vs-women
unemployment-rate-of-males-vs-females
unemployment-rate-women
unintentional-injuries-death-rate-by-age-group-who-mdb
united-nations-membership-status
united-nations-peacekeeping-forces
universal-health-coverage-index
universal-suffrage-lexical
universal-suffrage-men-lexical
universal-suffrage-women-lexical
unmet-need-for-contraception-share-of-married-women-of-reproductive-age
unpaid-parking-violations-per-diplomat
un-peacekeeping-forces
un-population-2024-vs-2022
un-projection-of-annual-infant-deaths
unsentenced-detainees-as-proportion-of-prison-population
unusually-high-precipitation-usa
upper-secondary-completion-rate-adjusted-gender-parity-index
uranium-production
urban-agglomerations-1-million-percent
urban-agglomerations-more-than-1-million
urban-and-rural-population
urban-and-rural-population-2050
urban-and-rural-population-stacked
urban-area-long-term
urban-improved-water-access-vs-rural-water-access
urbanization-vs-gdp
urban-land-area
urban-policies-population-dynamics
urban-pop-in-out-of-slums
urban-population-share-2050
urban-population-vs-female-labor-force-participation-rate
urban-population-with-improved-water
urban-share-european-commission
urban-vs-rural-majority
urban-vs-rural-population-safely-managed-sanitation
urban-vs-rural-population-using-at-least-basic-sanitation
urban-vs-rural-safely-managed-drinking-water-source
urban-vs-rural-using-at-least-basic-drinking-water
us-covid-19-share-people-vaccinated
us-covid-19-total-people-vaccinated
us-covid-number-fully-vaccinated
us-covid-share-fully-vaccinated
us-daily-covid-vaccine-doses-administered
us-daily-covid-vaccine-doses-per-100
us-education-expenditure-as-share-of-gdp-public-and-private-institutions
use-of-statins-for-primary-prevention-of-cardiovascular-disease
use-of-statins-for-secondary-prevention-amongst-eligibible-individuals
us-healthcare-expenditure
us-state-covid-vaccines-per-100
us-total-covid-19-vaccine-doses-administered
us-women-are-overrepresented-in-low-wage-occupations
utilization-of-statins
vaccination-coverage-by-income-in
vaccination-coverage-dpt-by-extreme-poverty
value-of-agricultural-production
varieties-democracy-vdem
various-measures-of-child-labour-incidence
various-measures-of-national-savinginvestment-compared-to-gdp-per-capita-in-international-dollars
various-measures-of-national-savinginvestment-per-capita-in-international-dollars
various-sources-of-the-total-value-of-exports-as-a-share-of-gdp
vegetable-oil-production
vegetable-oil-vs-gdp
vegetable-supply-per-person-vs-gdp-per-capita
views-ai-impact-society-next-20-years
views-of-americans-robot-vs-human-intelligence
views-safety-self-driving-car
vitamin-a-supplementation-coverage-rate-children-ages-6-59-months
voter-turnout-of-registered-voters
voter-turnout-of-voting-age-population
wanted-fertility-rate
warming-fossil-fuels-land-use
warm-season-deaths-climate
war-rate-by-type-project-mars
war-rate-correlates-of-war
waste-items-ocean-region
wastewater-safely-treated
water-basins-cooperation-plan
water-bodies-good-water-quality
water-per-protein-poore
water-productivity
water-withdrawals-per-capita
water-withdrawals-per-kg-poore
wealth-per-capita-by-asset-group-with-natural-capital-disaggregated-in-2014-us-dollars
weather-forecast-spending
weather-losses-share-gdp
weekly-area-burnt-by-wildfires
weekly-cumulative-share-of-the-area-burnt-by-wildfires-each-year
weekly-hours-dedicated-to-home-production-in-the-usa-by-employment-and-marriage-status
weekly-hours-worked-by-children-7-14-vs-gdp-per-capita-ppp
weekly-share-of-the-total-land-area-burnt-by-wildfires
weekly-work-hours-vs-gdp-per-capita
weighted-carbon-price-ets
were-flu-vaccines-available-in-the-country
whale-catch
whale-populations
whales-killed-per-decade
what-percentage-of-the-us-public-approves-of-working-wives
wheat-exports-ukraine-russia-perspective
wheat-production
wheat-yields
which-countries-include-malaria-vaccines-in-their-vaccination-schedules
who-americans-spend-their-time-with
who-vs-gbd-incidence-of-tetanus
wild-caught-fish
wildfire-numbers-usa
wild-fish-allocation
wild-fish-catch-gear-type
wildlife-exports
willingness-climate-action
wind-electricity-per-capita
wind-energy-consumption-by-region
wind-energy-consumption-vs-installed-wind-energy-capacity
wind-generation
wind-share-energy
wine-production
winter-temperature-anomalies
women-and-men-have-equal-rights-to-immovable-property
women-believe-husband-justified-beating-wife
women-business-and-the-law-index
women-can-apply-passport-same-as-men
women-can-obtain-divorce-same-as-men
women-can-open-bank-account-same-as-men
women-can-register-a-business-in-the-same-way-as-men
women-can-sign-a-contract-same-as-men
women-can-take-the-same-jobs-as-men
women-choose-where-to-live-same-way-as-men
women-civil-liberties-index
women-civil-society-participation-index
women-have-the-same-rights-to-remarry-as-men
women-high-blood-pressure
women-informed-decisions-health-sexual-relations
women-in-informal-employment-as-share-of-female-employment
women-married-by-age-15
women-married-by-age-18
women-participating-in-decisionmaking-vs-fertility
women-political-empowerment-index
women-political-empowerment-index-vs-electoral-democracy-index
women-political-participation-index
women-required-to-obey-husband
womens-economic-opportunity-2012-index
womens-educational-attainment-vs-fertility
womens-life-expectancy-at-birth
women-survival-to-age-65
womens-weekly-earnings-as-a-percentage-of-mens-by-age-bureau-of-labor-statistics-2017
women-who-experienced-sexual-violence-by-age-18
women-who-have-next-birth-parity-progression-ratio
work-hours-per-week
working-children-out-of-school-ages-7-14-vs-hours-worked-by-children-ages-7-14
working-hours-uk-millennium
working-hours-vs-hourly-wage
working-hours-vs-hourly-wage-excl-self-empl
world-crude-oil-price-vs-oil-consumption
world-population-comparison-historical-sources
world-population-level-education
world-population-projections-by-un-prospects-revision
world-population-supported-by-synthetic-nitrogen-fertilizers
world-population-with-and-without-fertilizer
world-trade-exports-constant-prices
year-country-was-certified-free-of-guinea-worm-disease
yearly-number-of-objects-launched-into-outer-space
year-of-maternal-neonatal-tetanus-mnt-elimination
years-colonized
years-lived-with-disability-vs-gdp-per-capita
years-lived-with-disability-vs-health-expenditure-per-capita
years-of-fossil-fuel-reserves-left
years-of-schooling-prados-de-la-escosura
yield-gap-vs-nitrogen-pollution
yields-key-staple-crops
yields-of-important-staple-crops
youth-literacy-female
youth-literacy-males
youth-mortality-rate
